# The testsuite is disabled by default.
#
# To build and run the tests use:
#
# fedpkg mockbuild --with testsuite
# or
# rpmbuild --rebuild --with testsuite samba.src.rpm
#
%bcond_with testsuite

# Build with internal talloc, tevent, tdb and ldb.
#
# fedpkg mockbuild --with=testsuite --with=includelibs
# or
# rpmbuild --rebuild --with=testsuite --with=includelibs samba.src.rpm
#
%bcond_with includelibs

# fedpkg mockbuild --with=ccache
%bcond_with ccache

# ctdb is enabled by default, you can disable it with: --without clustering
%bcond_without clustering

# Define _make_verbose if it doesn't exist (RHEL8)
%{!?_make_verbose:%define _make_verbose V=1 VERBOSE=1}

# Build with Active Directory Domain Controller support by default on Fedora
%if 0%{?fedora}
%bcond_without dc
%else
%bcond_with dc
%endif

# Build a libsmbclient package by default
%bcond_without libsmbclient

# Build a libwbclient package by default
%bcond_without libwbclient

# Build with winexe by default
%if 0%{?rhel}

%ifarch x86_64
%bcond_without winexe
%else
%bcond_with winexe
#endifarch
%endif

%else
%bcond_without winexe
%endif

# ppc64le excluded pending resolution of https://gcc.gnu.org/bugzilla/show_bug.cgi?id=104172
#%%ifarch aarch64 ppc64le s390x x86_64
%ifarch aarch64 s390x x86_64 riscv64
%bcond_without vfs_cephfs
%bcond_without ceph_mutex
%else
%bcond_with vfs_cephfs
%bcond_with ceph_mutex
#endifarch
%endif

%ifarch aarch64 ppc64le s390x x86_64
%bcond_without vfs_glusterfs
%else
%bcond_with vfs_glusterfs
#endifarch
%endif

# Build vfs_io_uring module by default on 64bit Fedora
%if 0%{?fedora} || 0%{?rhel} >= 8

%ifarch aarch64 ppc64le s390x x86_64 riscv64
%bcond_without vfs_io_uring
%else
%bcond_with vfs_io_uring
#endifarch
%endif

%else
%bcond_with vfs_io_uring
#endif fedora || rhel >= 8
%endif

# Build the ctdb-pcp-pmda package by default on Fedora, except for i686 where
# pcp is no longer supported
%if 0%{?fedora}
%ifnarch i686
%bcond_without pcp_pmda
%endif
%else
%bcond_with pcp_pmda
%endif

# Build the etcd helpers by default on Fedora
%if 0%{?fedora}
%bcond_without etcd_mutex
%else
%bcond_with etcd_mutex
%endif

%if 0%{?fedora} || 0%{?rhel} >= 9
%bcond_without gpupdate
%else
%bcond_with gpupdate
%endif

%define samba_requires_eq()  %(LC_ALL="C" echo '%*' | xargs -r rpm -q --qf 'Requires: %%{name} = %%{epoch}:%%{version}\\n' | sed -e 's/ (none):/ /' -e 's/ 0:/ /' | grep -v "is not")

%global samba_version 4.21.6
%global baserelease 100
# This should be rc1 or %%nil
%global pre_release %nil

%global samba_release %{baserelease}
%if "x%{?pre_release}" != "x"
%global samba_release 0.%{baserelease}.%{pre_release}
%endif

%if %{with dc} || %{with testsuite}
%global required_mit_krb5 1.20.1
%else
%global required_mit_krb5 1.15.1
%endif

# This is a network daemon, do a hardened build
# Enables PIE and full RELRO protection
%global _hardened_build 1
# Samba cannot be linked with -Wl,-z,defs (from hardened build config)
# For exmple the samba-cluster-support library is marked to allow undefined
# symbols in the samba build.
#
# https://src.fedoraproject.org/rpms/redhat-rpm-config/blob/master/f/buildflags.md
%undefine _strict_symbol_defs_build

%global _systemd_extra "Environment=KRB5CCNAME=FILE:/run/samba/krb5cc_samba"

# Make a copy of this variable to prevent repeated evaluation of the
# embedded shell command.  Avoid recursive macro definition if undefined.
%{?python3_sitearch: %global python3_sitearch %{python3_sitearch}}

Name:           samba
Version:        %{samba_version}
Release:        %{samba_release}%{?dist}

%if 0%{?fedora}
Epoch:          2
%else
Epoch:          0
%endif

%global samba_depver %{epoch}:%{version}-%{release}

Summary:        Server and Client software to interoperate with Windows machines
License:        GPL-3.0-or-later AND LGPL-3.0-or-later
URL:            https://www.samba.org

# This is a xz recompressed file of https://ftp.samba.org/pub/samba/samba-%%{version}%%{pre_release}.tar.gz
Source0:        https://ftp.samba.org/pub/samba/samba-%{version}%{pre_release}.tar.gz#/samba-%{version}%{pre_release}.tar.xz
Source1:        https://ftp.samba.org/pub/samba/samba-%{version}%{pre_release}.tar.asc
Source2:        gpgkey-AA99442FB680B620.gpg

# Red Hat specific replacement-files
Source10:       samba.logrotate
Source11:       smb.conf.vendor
Source12:       smb.conf.example
Source13:       pam_winbind.conf
Source14:       samba.pamd
Source15:       usershares.conf.vendor
Source16:       samba-systemd-sysusers.conf
Source17:       samba-usershares-systemd-sysusers.conf
Source18:       samba-winbind-systemd-sysusers.conf

Source101:      script.options

Source201:      README.downgrade

Patch1: remove-talloc-ldb-requires-from-samba-policy.patch

Requires(pre): %{name}-common = %{samba_depver}
Requires: %{name}-common = %{samba_depver}
Requires: %{name}-common-libs = %{samba_depver}
Requires: %{name}-common-tools = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-libs = %{samba_depver}
Requires: %{name}-dcerpc = %{samba_depver}
Requires: libnetapi = %{samba_depver}
%if %{with libwbclient}
Requires(post): libwbclient = %{samba_depver}
Requires: libwbclient = %{samba_depver}
%endif

Requires: pam

Provides: samba4 = %{samba_depver}
Obsoletes: samba4 < %{samba_depver}

# We don't build it outdated docs anymore
Provides: samba-doc = %{samba_depver}
Obsoletes: samba-doc < %{samba_depver}

# Is not supported yet
Provides: samba-domainjoin-gui = %{samba_depver}
Obsoletes: samba-domainjoin-gui < %{samba_depver}

# SWAT been deprecated and removed from samba
Provides: samba-swat = %{samba_depver}
Obsoletes: samba-swat < %{samba_depver}

Provides: samba4-swat = %{samba_depver}
Obsoletes: samba4-swat < %{samba_depver}

Provides: bundled(libreplace)

BuildRequires: make
BuildRequires: gcc
BuildRequires: glibc-gconv-extra
BuildRequires: avahi-devel
BuildRequires: bison
BuildRequires: cups-devel
BuildRequires: dbus-devel
BuildRequires: docbook-style-xsl
BuildRequires: e2fsprogs-devel
BuildRequires: flex
BuildRequires: gawk
BuildRequires: gnupg2
BuildRequires: gnutls-devel >= 3.4.7
BuildRequires: gpgme-devel
BuildRequires: jansson-devel
BuildRequires: krb5-devel >= %{required_mit_krb5}
BuildRequires: libacl-devel
BuildRequires: libaio-devel
BuildRequires: libarchive-devel
BuildRequires: libattr-devel
BuildRequires: libcap-devel
BuildRequires: libicu-devel
BuildRequires: libcmocka-devel
BuildRequires: libtirpc-devel
BuildRequires: libuuid-devel
BuildRequires: libxslt
BuildRequires: lmdb
%if %{with winexe}
BuildRequires: mingw32-gcc
BuildRequires: mingw64-gcc
%endif
BuildRequires: ncurses-devel
BuildRequires: openldap-devel
BuildRequires: pam-devel
BuildRequires: perl-interpreter
BuildRequires: perl-generators
BuildRequires: perl(Archive::Tar)
BuildRequires: perl(Test::More)
BuildRequires: popt-devel
BuildRequires: python3-cryptography
BuildRequires: python3-devel
BuildRequires: python3-dns
BuildRequires: python3-requests
BuildRequires: python3-setuptools
BuildRequires: quota-devel
BuildRequires: readline-devel
BuildRequires: rpcgen
BuildRequires: rpcsvc-proto-devel
BuildRequires: sed
BuildRequires: systemd-rpm-macros
BuildRequires: libtasn1-devel
# We need asn1Parser
BuildRequires: libtasn1-tools
BuildRequires: xfsprogs-devel
BuildRequires: xz
BuildRequires: zlib-devel >= 1.2.3

BuildRequires: pkgconfig(libsystemd)

%ifnarch i686 riscv64
%if 0%{?fedora} >= 37
BuildRequires: mold
%endif
%endif

%if %{with vfs_glusterfs}
BuildRequires: glusterfs-api-devel >= 6.0
%endif

%if %{with vfs_cephfs}
BuildRequires: libcephfs-devel
%endif

%if %{with vfs_io_uring}
BuildRequires: liburing-devel >= 0.4
%endif

%if %{with pcp_pmda}
BuildRequires: pcp-libs-devel
%endif
%if %{with ceph_mutex}
BuildRequires: librados-devel
%endif
%if %{with etcd_mutex}
BuildRequires: python3-etcd
%endif

%if %{with gpupdate}
BuildRequires: cepces-certmonger >= 0.3.8
%endif

# pidl requirements
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(FindBin)
BuildRequires: perl(Parse::Yapp)

# lmdb-devel is required for the mdb ldb module, if samba is configured
# to build includelibs we need lmdb-devel for building that module on our own
BuildRequires: lmdb-devel

%if %{with dc} || %{with testsuite}
BuildRequires: bind
BuildRequires: krb5-server >= %{required_mit_krb5}
%if 0%{?fedora} || 0%{?rhel} >= 9
BuildRequires: python3-dateutil
%else
BuildRequires: python3-iso8601
%endif
BuildRequires: python3-gpg
BuildRequires: python3-markdown
BuildRequires: python3-pyasn1 >= 0.4.8
BuildRequires: python3-setproctitle

#endif with dc || with testsuite
%endif

# filter out perl requirements pulled in from examples in the docdir.
%global __requires_exclude_from ^%{_docdir}/.*$
%global __provides_exclude_from ^%{_docdir}/.*$

### SAMBA
%description
Samba is the standard Windows interoperability suite of programs for Linux and
Unix.

### CLIENT
%package client
Summary: Samba client programs
Requires(pre): %{name}-common = %{samba_depver}
Requires: %{name}-common = %{samba_depver}
Requires: %{name}-common-libs = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}
%if %{with libsmbclient}
Requires: libsmbclient = %{samba_depver}
%endif
%if %{with libwbclient}
Requires: libwbclient = %{samba_depver}
%endif

Provides: samba4-client = %{samba_depver}
Obsoletes: samba4-client < %{samba_depver}

Requires(post): %{_sbindir}/update-alternatives
Requires(postun): %{_sbindir}/update-alternatives

Provides: ldb-tools = %{samba_depver}
Obsoletes: ldb-tools < %{samba_depver}

Provides: tdb-tools = %{samba_depver}
Obsoletes: tdb-tools < %{samba_depver}

Provides: bundled(libreplace)

%description client
The %{name}-client package provides some SMB/CIFS clients to complement
the built-in SMB/CIFS filesystem in Linux. These clients allow access
of SMB/CIFS shares and printing to SMB/CIFS printers.

### CLIENT-LIBS
%package client-libs
Summary: Samba client libraries
Requires(pre): %{name}-common = %{samba_depver}
Requires: %{name}-common = %{samba_depver}
Requires: %{name}-common-libs = %{samba_depver}
%if %{with libwbclient}
Requires: libwbclient = %{samba_depver}
%endif
Requires: krb5-libs >= %{required_mit_krb5}
# This is needed for charset conversion
Requires: glibc-gconv-extra

%description client-libs
The samba-client-libs package contains internal libraries needed by the
SMB/CIFS clients.

### COMMON
%package common
Summary: Files used by both Samba servers and clients
BuildArch: noarch

Requires(post): (systemd-standalone-tmpfiles or systemd)
%if 0%{?fedora}
Recommends:     logrotate
%endif

Provides: samba4-common = %{samba_depver}
Obsoletes: samba4-common < %{samba_depver}

%description common
samba-common provides files necessary for both the server and client
packages of Samba.

### COMMON-LIBS
%package common-libs
Summary: Libraries used by both Samba servers and clients
Requires(pre): samba-common = %{samba_depver}
Requires: samba-common = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}
%if %{with libwbclient}
Requires: libwbclient = %{samba_depver}
%endif

Provides: bundled(libreplace)

%if %{without dc} && %{without testsuite}
Obsoletes: samba-dc < %{samba_depver}
Obsoletes: samba-dc-libs < %{samba_depver}
Obsoletes: samba-dc-bind-dlz < %{samba_depver}
%endif

# ctdb-tests package has been dropped if we do not build the testsuite
%if %{with clustering}
%if %{without testsuite}
Obsoletes: ctdb-tests < %{samba_depver}
Obsoletes: ctdb-tests-debuginfo < %{samba_depver}
# endif without testsuite
%endif
# endif with clustering
%endif

%if %{without vfs_glusterfs}
Obsoletes: samba-vfs-glusterfs < %{samba_depver}
# endif without vfs_glusterfs
%endif

%description common-libs
The samba-common-libs package contains internal libraries needed by the
SMB/CIFS clients.

### COMMON-TOOLS
%package common-tools
Summary: Tools for Samba clients
Requires: samba-common-libs = %{samba_depver}
Requires: samba-client-libs = %{samba_depver}
Requires: samba-libs = %{samba_depver}
Requires: samba-ldb-ldap-modules = %{samba_depver}
Requires: libnetapi = %{samba_depver}
%if %{with libwbclient}
Requires: libwbclient = %{samba_depver}
%endif

Provides: bundled(libreplace)

%description common-tools
The samba-common-tools package contains tools for SMB/CIFS clients.

### SAMBA-TOOLS
%package tools
Summary: Tools for Samba servers
# samba-tool needs python3-samba
Requires: python3-%{name} = %{samba_depver}
# samba-tool needs python3-samba-dc also on non-dc build
Requires: python3-%{name}-dc = %{samba_depver}
%if %{with dc}
# samba-tool needs mdb_copy and tdbackup for domain backup or upgrade provision
Requires: lmdb
Requires: tdb-tools
Requires: python3-gpg
%endif

%description tools
The samba-tools package contains tools for Samba servers
and for GPO management on domain members.

### RPC
%package dcerpc
Summary: DCE RPC binaries
Requires: samba-common-libs = %{samba_depver}
Requires: samba-client-libs = %{samba_depver}
Requires: samba-libs = %{samba_depver}
Requires: libnetapi = %{samba_depver}
%if %{with libwbclient}
Requires: libwbclient = %{samba_depver}
%endif

%description dcerpc
The samba-dcerpc package contains binaries that serve DCERPC over named pipes.

### DC
%if %{with dc} || %{with testsuite}
%package dc
Summary: Samba AD Domain Controller
Requires: %{name} = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-common-libs = %{samba_depver}
Requires: %{name}-common-tools = %{samba_depver}
Requires: %{name}-tools = %{samba_depver}
Requires: %{name}-libs = %{samba_depver}
Requires: %{name}-dc-provision = %{samba_depver}
Requires: %{name}-dc-libs = %{samba_depver}
Requires: %{name}-winbind = %{samba_depver}

%if %{with libwbclient}
Requires(post): libwbclient = %{samba_depver}
Requires: libwbclient = %{samba_depver}
%endif

Requires: ldb-tools
Requires: python3-setproctitle
# Force using libldb version to be the same as build version
# Otherwise LDB modules will not be loaded and samba-tool will fail
# See bug 1507420
%samba_requires_eq libldb

Requires: python3-%{name} = %{samba_depver}
Requires: python3-%{name}-dc = %{samba_depver}
Requires: krb5-server >= %{required_mit_krb5}
Requires: bind-utils

Provides: samba4-dc = %{samba_depver}
Obsoletes: samba4-dc < %{samba_depver}

Provides: bundled(libreplace)

%description dc
The samba-dc package provides AD Domain Controller functionality

### DC-PROVISION
%package dc-provision
Summary: Samba AD files to provision a DC
BuildArch: noarch

%description dc-provision
The samba-dc-provision package provides files to setup a domain controller

#endif with dc || with testsuite
%endif

### DC-LIBS
%package dc-libs
Summary: Samba AD Domain Controller Libraries
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-common-libs = %{samba_depver}
Requires: %{name}-libs = %{samba_depver}

Provides: samba4-dc-libs = %{samba_depver}
Obsoletes: samba4-dc-libs < %{samba_depver}

Provides: bundled(libreplace)

%description dc-libs
The %{name}-dc-libs package contains the libraries needed by the DC to
link against the SMB, RPC and other protocols.

%if %{with dc} || %{with testsuite}
### DC-BIND
%package dc-bind-dlz
Summary: Bind DLZ module for Samba AD
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-common = %{samba_depver}
Requires: %{name}-dc-libs = %{samba_depver}
Requires: %{name}-dc = %{samba_depver}
Requires: %{name}-libs = %{samba_depver}
Requires: bind

Provides: bundled(libreplace)

%description dc-bind-dlz
The %{name}-dc-bind-dlz package contains the libraries for bind to manage all
name server related details of Samba AD.
#endif with dc
%endif

### DEVEL
%package devel
Summary: Developer tools for Samba libraries
Requires: %{name}-libs = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}
%if %{with dc}
Requires: %{name}-dc-libs = %{samba_depver}
%endif
Requires: libnetapi = %{samba_depver}

Provides: samba4-devel = %{samba_depver}
Obsoletes: samba4-devel < %{samba_depver}

%description devel
The %{name}-devel package contains the header files for the libraries
needed to develop programs that link against the SMB, RPC and other
libraries in the Samba suite.

### CEPH
%if %{with vfs_cephfs}
%package vfs-cephfs
Summary: Samba VFS module for Ceph distributed storage system
Requires: libcephfs2 >= 16.2.0
Requires: %{name} = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-libs = %{samba_depver}

Provides: bundled(libreplace)

%description vfs-cephfs
Samba VFS module for Ceph distributed storage system integration.
#endif with vfs_cephfs
%endif

### IOURING
%if %{with vfs_io_uring}
%package vfs-iouring
Summary: Samba VFS module for io_uring
Requires: %{name} = %{samba_depver}
Requires: %{name}-libs = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}

Provides: bundled(libreplace)

%description vfs-iouring
Samba VFS module for io_uring instance integration.
#endif with vfs_io_uring
%endif

### GLUSTER
%if %{with vfs_glusterfs}
%package vfs-glusterfs
Summary: Samba VFS module for GlusterFS
Requires: glusterfs-api >= 6.0
Requires: %{name} = %{samba_depver}
Requires: %{name}-common-libs = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-libs = %{samba_depver}
%if %{with libwbclient}
Requires: libwbclient = %{samba_depver}
%endif

Obsoletes: samba-glusterfs < %{samba_depver}
Provides: samba-glusterfs = %{samba_depver}

Provides: bundled(libreplace)

%description vfs-glusterfs
Samba VFS module for GlusterFS integration.
%endif

### GPUPDATE
%if %{with gpupdate}
%package gpupdate
Summary: Samba GPO support for clients
Requires: cepces-certmonger
Requires: certmonger
Requires: %{name}-ldb-ldap-modules = %{samba_depver}
Requires: python3-%{name} = %{samba_depver}
# samba-tool needs python3-samba-dc also on non-dc build
Requires: python3-%{name}-dc = %{samba_depver}

%description gpupdate
This package provides the samba-gpupdate tool to apply Group Policy Objects
(GPO) on Samba clients.

#endif with gpupdate
%endif

### KRB5-PRINTING
%package krb5-printing
Summary: Samba CUPS backend for printing with Kerberos
Requires(pre): %{name}-client
Requires: %{name}-client = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}

Requires(post): %{_sbindir}/update-alternatives
Requires(postun): %{_sbindir}/update-alternatives

%description krb5-printing
If you need Kerberos for print jobs to a printer connection to cups via the SMB
backend, then you need to install that package. It will allow cups to access
the Kerberos credentials cache of the user issuing the print job.

### LDB-LDAP-MODULES
%package ldb-ldap-modules
Summary: Samba ldap modules for ldb
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-common-libs = %{samba_depver}

%description ldb-ldap-modules
This package contains the ldb ldap modules required by samba-tool and
samba-gpupdate.

### LIBS
%package libs
Summary: Samba libraries
Requires: %{name}-common-libs = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}
%if %{with libwbclient}
Requires: libwbclient = %{samba_depver}
%endif

Provides: samba4-libs = %{samba_depver}
Obsoletes: samba4-libs < %{samba_depver}

Provides: bundled(libreplace)

%description libs
The %{name}-libs package contains the libraries needed by programs that link
against the SMB, RPC and other protocols provided by the Samba suite.

### LIBNETAPI
%package -n libnetapi
Summary: The NETAPI library
Requires(pre): %{name}-common = %{samba_depver}
Requires: %{name}-common = %{samba_depver}
Requires: %{name}-common-libs = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}

%description -n libnetapi
This contains the NETAPI library from the Samba suite.

%package -n libnetapi-devel
Summary: Developer tools for the NETAPI library
Requires: libnetapi = %{samba_depver}

%description -n libnetapi-devel
The libnetapi-devel package contains the header files and libraries needed to
develop programs that link against the NETAPI library in the Samba suite.

### LIBSMBCLIENT
%if %{with libsmbclient}
%package -n libsmbclient
Summary: The SMB client library
Requires(pre): %{name}-common = %{samba_depver}
Requires: %{name}-common = %{samba_depver}
Requires: %{name}-common-libs = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}
%if %{with libwbclient}
Requires: libwbclient = %{samba_depver}
%endif

%description -n libsmbclient
The libsmbclient contains the SMB client library from the Samba suite.

%package -n libsmbclient-devel
Summary: Developer tools for the SMB client library
Requires: libsmbclient = %{samba_depver}

%description -n libsmbclient-devel
The libsmbclient-devel package contains the header files and libraries needed
to develop programs that link against the SMB client library in the Samba
suite.
#endif {with libsmbclient}
%endif

### LIBWBCLIENT
%if %{with libwbclient}
%package -n libwbclient
Summary: The winbind client library
Requires: %{name}-client-libs = %{samba_depver}
Conflicts: sssd-libwbclient

%description -n libwbclient
The libwbclient package contains the winbind client library from the Samba
suite.

%package -n libwbclient-devel
Summary: Developer tools for the winbind library
Requires: libwbclient = %{samba_depver}
Conflicts: sssd-libwbclient-devel

Provides: samba-winbind-devel = %{samba_depver}
Obsoletes: samba-winbind-devel < %{samba_depver}

%description -n libwbclient-devel
The libwbclient-devel package provides developer tools for the wbclient
library.
#endif {with libwbclient}
%endif

### PYTHON3
%package -n python3-%{name}
Summary: Samba Python3 libraries
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-common-libs = %{samba_depver}
Requires: %{name}-libs = %{samba_depver}
Requires: %{name}-dc-libs = %{samba_depver}
Requires: python3-cryptography
Requires: python3-dns
Requires: python3-ldb
Requires: python3-requests
Requires: python3-talloc
Requires: python3-tdb
Requires: python3-tevent
%if %{with libsmbclient}
Requires: libsmbclient = %{samba_depver}
%endif
%if %{with libwbclient}
Requires: libwbclient = %{samba_depver}
%endif

Provides: python3-talloc = %{samba_depver}
Obsoletes: python3-talloc < %{samba_depver}
Provides: pytalloc = %{samba_depver}
Obsoletes: pytalloc < %{samba_depver}

Provides: python3-tdb = %{samba_depver}
Obsoletes: python3-tdb < %{samba_depver}
Provides: python-tdb = %{samba_depver}
Obsoletes: python-tdb < %{samba_depver}

Provides: python3-tevent = %{samba_depver}
Obsoletes: python3-tevent < %{samba_depver}
Provides: python-tevent = %{samba_depver}
Obsoletes: python-tevent < %{samba_depver}

Provides: python3-ldb = %{samba_depver}
Obsoletes: python3-ldb < %{samba_depver}
Provides: pyldb = %{samba_depver}
Obsoletes: pyldb < %{samba_depver}

Provides: bundled(libreplace)

%description -n python3-%{name}
The python3-%{name} package contains the Python 3 libraries needed by programs
that use SMB, RPC and other Samba provided protocols in Python 3 programs.

%package -n python3-samba-test
Summary: Samba Python libraries
Requires: python3-%{name} = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-libs = %{samba_depver}

%description -n python3-samba-test
The python3-%{name}-test package contains the Python libraries used by the test suite of Samba.
If you want to run full set of Samba tests, you need to install this package.

%package -n python3-samba-dc
Summary: Samba Python libraries for Samba AD
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-dc-libs = %{samba_depver}
Requires: python3-%{name} = %{samba_depver}
# for ms_forest_updates_markdown.py and ms_schema_markdown.py
Requires: python3-markdown

%description -n python3-samba-dc
The python3-%{name}-dc package contains the Python libraries needed by programs
to manage Samba AD.

### PIDL
%package pidl
Summary: Perl IDL compiler
Requires: perl-interpreter
Requires: perl(FindBin)
Requires: perl(Parse::Yapp)
BuildArch: noarch

Provides: samba4-pidl = %{samba_depver}
Obsoletes: samba4-pidl < %{samba_depver}

%description pidl
The %{name}-pidl package contains the Perl IDL compiler used by Samba
and Wireshark to parse IDL and similar protocols

### TEST
%package test
Summary: Testing tools for Samba servers and clients
Requires: %{name} = %{samba_depver}
Requires: %{name}-common = %{samba_depver}
Requires: %{name}-winbind = %{samba_depver}

Requires: %{name}-common-libs = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-libs = %{samba_depver}
Requires: %{name}-test-libs = %{samba_depver}
%if %{with dc} || %{with testsuite}
Requires: %{name}-dc-libs = %{samba_depver}
%endif
Requires: %{name}-libs = %{samba_depver}
Requires: libnetapi = %{samba_depver}
%if %{with libsmbclient}
Requires: libsmbclient = %{samba_depver}
%endif
%if %{with libwbclient}
Requires: libwbclient = %{samba_depver}
%endif
Requires: python3-%{name} = %{samba_depver}
Requires: perl(Archive::Tar)

Provides: samba4-test = %{samba_depver}
Obsoletes: samba4-test < %{samba_depver}

Provides: bundled(libreplace)

%description test
%{name}-test provides testing tools for both the server and client
packages of Samba.

### TEST-LIBS
%package test-libs
Summary: Libraries need by the testing tools for Samba servers and clients
Requires: %{name}-common-libs = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-libs = %{samba_depver}
%if %{with libwbclient}
Requires: libwbclient = %{samba_depver}
%endif

Provides: %{name}-test-devel = %{samba_depver}
Obsoletes: %{name}-test-devel < %{samba_depver}

Provides: bundled(libreplace)

%description test-libs
%{name}-test-libs provides libraries required by the testing tools.

### USERSHARES
%package usershares
Summary: Provides support for non-root user shares
Requires: %{name} = %{samba_depver}
Requires: %{name}-common-tools = %{samba_depver}

%description usershares
Installing this package will provide a configuration file, group and
directories to support non-root user shares. You can configure them
as a user using the `net usershare` command.

### WINBIND
%package winbind
Summary: Samba winbind
Requires(pre): %{name}-common = %{samba_depver}
Requires: %{name}-common = %{samba_depver}
Requires: %{name}-common-libs = %{samba_depver}
Requires(post): %{name}-common-libs = %{samba_depver}
Requires: %{name}-common-tools = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}
Requires(post): %{name}-client-libs = %{samba_depver}
Requires: %{name}-libs = %{samba_depver}
Requires(post): %{name}-libs = %{samba_depver}
Requires: %{name}-winbind-modules = %{samba_depver}
Suggests: %{name}-tools = %{samba_depver}

%if %{with libwbclient}
Requires(post): libwbclient = %{samba_depver}
Requires: libwbclient = %{samba_depver}
%endif
Requires: %{name}-dcerpc = %{samba_depver}

Provides: samba4-winbind = %{samba_depver}
Obsoletes: samba4-winbind < %{samba_depver}

# Old NetworkManager expects the dispatcher scripts in a different place
Conflicts: NetworkManager < 1.20

Provides: bundled(libreplace)

%description winbind
The samba-winbind package provides the winbind NSS library, and some client
tools.  Winbind enables Linux to be a full member in Windows domains and to use
Windows user and group accounts on Linux.

### WINBIND-CLIENTS
%package winbind-clients
Summary: Samba winbind clients
Requires: %{name}-common = %{samba_depver}
Requires: %{name}-common-libs = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-libs = %{samba_depver}
Requires: %{name}-winbind = %{samba_depver}
%if %{with libwbclient}
Requires: libwbclient = %{samba_depver}
%endif

Provides: samba4-winbind-clients = %{samba_depver}
Obsoletes: samba4-winbind-clients < %{samba_depver}

Provides: bundled(libreplace)

%description winbind-clients
The samba-winbind-clients package provides the wbinfo and ntlm_auth
tool.

### WINBIND-KRB5-LOCATOR
%package winbind-krb5-locator
Summary: Samba winbind krb5 locator
%if %{with libwbclient}
Requires: libwbclient = %{samba_depver}
Requires: %{name}-winbind = %{samba_depver}
%else
Requires: %{name}-libs = %{samba_depver}
%endif
Requires: samba-client-libs = %{samba_depver}

Provides: samba4-winbind-krb5-locator = %{samba_depver}
Obsoletes: samba4-winbind-krb5-locator < %{samba_depver}

# Handle winbind_krb5_locator.so as alternatives to allow
# IPA AD trusts case where it should not be used by libkrb5
# The plugin will be diverted to /dev/null by the FreeIPA
# freeipa-server-trust-ad subpackage due to higher priority
# and restored to the proper one on uninstall
Requires(post): %{_sbindir}/update-alternatives
Requires(postun): %{_sbindir}/update-alternatives
Requires(preun): %{_sbindir}/update-alternatives

Provides: bundled(libreplace)

%description winbind-krb5-locator
The winbind krb5 locator is a plugin for the system kerberos library to allow
the local kerberos library to use the same KDC as samba and winbind use

### WINBIND-MODULES
%package winbind-modules
Summary: Samba winbind modules
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-libs = %{samba_depver}
%if %{with libwbclient}
Requires: libwbclient = %{samba_depver}
%endif
Requires: pam

Provides: bundled(libreplace)

%description winbind-modules
The samba-winbind-modules package provides the NSS library and a PAM module
necessary to communicate to the Winbind Daemon

### WINEXE
%if %{with winexe}
%package winexe
Summary: Samba Winexe Windows Binary
License: GPL-3.0-only
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-common-libs = %{samba_depver}

Provides: bundled(libreplace)

%description winexe
Winexe is a Remote Windows-command executor
%endif

### CTDB
%if %{with clustering}
%package -n ctdb
Summary: A Clustered Database based on Samba's Trivial Database (TDB)

Requires: %{name}-common-libs = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}
Requires: %{name}-winbind-clients = %{samba_depver}

Requires: coreutils
# for ps and killall
Requires: psmisc
Requires: sed
Requires: tdb-tools
Requires: gawk
# for pkill and pidof:
Requires: procps-ng
# for netstat:
Requires: net-tools
Requires: ethtool
# for ip:
Requires: iproute
Requires: iptables
# for flock, getopt, kill:
Requires: util-linux

Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

Provides: bundled(libreplace)

%description -n ctdb
CTDB is a cluster implementation of the TDB database used by Samba and other
projects to store temporary data. If an application is already using TDB for
temporary data it is very easy to convert that application to be cluster aware
and use CTDB instead.

%if %{with testsuite}
### CTDB-TEST
%package -n ctdb-tests
Summary: CTDB clustered database test suite

Requires: %{name}-common-libs = %{samba_depver}
Requires: %{name}-client-libs = %{samba_depver}

Requires: ctdb = %{samba_depver}
Recommends: nc

Provides: ctdb-devel = %{samba_depver}
Obsoletes: ctdb-devel < %{samba_depver}

%description -n ctdb-tests
Test suite for CTDB.
CTDB is a cluster implementation of the TDB database used by Samba and other
projects to store temporary data. If an application is already using TDB for
temporary data it is very easy to convert that application to be cluster aware
and use CTDB instead.

#endif with testsuite
%endif

%if %{with pcp_pmda}

%package -n ctdb-pcp-pmda
Summary: CTDB PCP pmda support
Requires: ctdb = %{samba_depver}
Requires: pcp-libs
Requires: %{name}-client-libs = %{samba_depver}

%description -n ctdb-pcp-pmda
Performance Co-Pilot (PCP) support for CTDB

#endif with pcp_pmda
%endif

%if %{with etcd_mutex}

%package -n ctdb-etcd-mutex
Summary: CTDB ETCD mutex helper
Requires: ctdb = %{samba_depver}
Requires: python3-etcd

%description -n ctdb-etcd-mutex
Support for using an existing ETCD cluster as a mutex helper for CTDB

#endif with etcd_mutex
%endif

%if %{with ceph_mutex}

%package -n ctdb-ceph-mutex
Summary: CTDB ceph mutex helper
Requires: ctdb = %{samba_depver}

%description -n ctdb-ceph-mutex
Support for using an existing CEPH cluster as a mutex helper for CTDB

#endif with ceph_mutex
%endif

#endif with clustering
%endif



%prep
%if 0%{?fedora} || 0%{?rhel} >= 9
xzcat %{SOURCE0} | %{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data=-
%else
xzcat %{SOURCE0} | gpgv2 --quiet --keyring %{SOURCE2} %{SOURCE1} -
%endif
%autosetup -n samba-%{version}%{pre_release} -p1

# Make sure we do not build with heimdal code
rm -rfv third_party/heimdal

%build
%global _talloc_lib ,talloc,pytalloc,pytalloc-util
%global _tevent_lib ,tevent,pytevent
%global _tdb_lib ,tdb,pytdb
%global _ldb_lib ,ldb,pyldb,pyldb-util

%global _samba_libraries !popt%{_talloc_lib}%{_tevent_lib}%{_tdb_lib}%{_ldb_lib}

%global _samba_idmap_modules idmap_ad,idmap_rid,idmap_ldap,idmap_hash,idmap_tdb2
%global _samba_pdb_modules pdb_tdbsam,pdb_ldap,pdb_smbpasswd,pdb_wbc_sam,pdb_samba4

%if %{with testsuite}
%global _samba_auth_modules auth_wbc,auth_unix,auth_server,auth_samba4,auth_skel
%global _samba_vfs_modules vfs_dfs_samba4,vfs_fake_dfq
%else
%global _samba_auth_modules auth_wbc,auth_unix,auth_server,auth_samba4
%global _samba_vfs_modules vfs_dfs_samba4
%endif

%global _samba_modules %{_samba_idmap_modules},%{_samba_pdb_modules},%{_samba_auth_modules},%{_samba_vfs_modules}

%global _libsmbclient %nil
%global _libwbclient %nil

%if %{without libsmbclient}
%global _libsmbclient smbclient,
%endif

%if %{without libwbclient}
%global _libwbclient wbclient,
%endif

%global _samba_private_libraries %{_libsmbclient}%{_libwbclient}

# TODO: resolve underlinked python modules
export python_LDFLAGS="$(echo %{__global_ldflags} | sed -e 's/-Wl,-z,defs//g')"

# Use the mold linker if possible
export python_LDFLAGS="$(echo %{__global_ldflags} | sed -e 's/-Wl,-z,defs//g')"

%ifnarch i686 riscv64
%if 0%{?fedora} >= 37
export LDFLAGS="%{__global_ldflags} -fuse-ld=mold"
export python_LDFLAGS="$(echo ${LDFLAGS} | sed -e 's/-Wl,-z,defs//g')"
#endif fedora >= 37
%endif
#endif narch i686
%endif

# Add support for mock ccache plugin
%if %{with ccache}
CCACHE="$(command -v ccache)"
if [ -n "${CCACHE}" ]; then
    ${CCACHE} -s
    export CC="${CCACHE} gcc"
fi
%endif

%configure \
        --enable-fhs \
        --with-piddir=/run \
        --with-sockets-dir=/run/samba \
        --with-modulesdir=%{_libdir}/samba \
        --with-pammodulesdir=%{_libdir}/security \
        --with-lockdir=/var/lib/samba/lock \
        --with-statedir=/var/lib/samba \
        --with-cachedir=/var/lib/samba \
        --disable-rpath-install \
        --with-shared-modules=%{_samba_modules} \
        --bundled-libraries=%{_samba_libraries} \
        --with-pam \
        --with-pie \
        --with-relro \
        --without-fam \
%if (%{without libsmbclient}) || (%{without libwbclient})
        --private-libraries=%{_samba_private_libraries} \
%endif
        --with-system-mitkrb5 \
        --with-experimental-mit-ad-dc \
%if %{without dc} && %{without testsuite}
        --without-ad-dc \
%endif
%if %{without vfs_glusterfs}
        --disable-glusterfs \
%endif
%if %{with clustering}
        --with-cluster-support \
%endif
%if %{with testsuite}
        --enable-selftest \
%endif
%if %{with pcp_pmda}
        --enable-pmda \
%endif
%if %{with ceph_mutex}
        --enable-ceph-reclock \
%endif
%if %{with etcd_mutex}
        --enable-etcd-reclock \
%endif
        --with-profiling-data \
        --with-systemd \
        --with-quotas \
        --systemd-install-services \
        --with-systemddir=/usr/lib/systemd/system \
        --systemd-smb-extra=%{_systemd_extra} \
        --systemd-nmb-extra=%{_systemd_extra} \
        --systemd-winbind-extra=%{_systemd_extra} \
%if %{with clustering}
        --systemd-ctdb-extra=%{_systemd_extra} \
%endif
        --systemd-samba-extra=%{_systemd_extra}

# Do not use %%make_build, make is just a wrapper around waf in Samba!
%{__make} %{?_smp_mflags} %{_make_verbose}

pushd pidl
%__perl Makefile.PL PREFIX=%{_prefix}

%make_build
popd

%install
# Do not use %%make_install, make is just a wrapper around waf in Samba!
%{__make} %{?_smp_mflags} %{_make_verbose} install DESTDIR=%{buildroot}

install -d -m 0755 %{buildroot}/usr/{sbin,bin}
install -d -m 0755 %{buildroot}%{_libdir}/security
install -d -m 0755 %{buildroot}/var/lib/samba
install -d -m 0755 %{buildroot}/var/lib/samba/drivers
install -d -m 0755 %{buildroot}/var/lib/samba/lock
install -d -m 0755 %{buildroot}/var/lib/samba/private
install -d -m 0755 %{buildroot}/var/lib/samba/scripts
install -d -m 0755 %{buildroot}/var/lib/samba/sysvol
install -d -m 0755 %{buildroot}/var/lib/samba/usershares
install -d -m 0755 %{buildroot}/var/lib/samba/winbindd_privileged
install -d -m 0755 %{buildroot}/var/log/samba/old
install -d -m 0755 %{buildroot}/var/spool/samba
install -d -m 0755 %{buildroot}/run/samba
install -d -m 0755 %{buildroot}/run/winbindd
install -d -m 0755 %{buildroot}/%{_libdir}/samba
install -d -m 0755 %{buildroot}/%{_libdir}/samba/ldb
install -d -m 0755 %{buildroot}/%{_libdir}/pkgconfig

touch %{buildroot}%{_libexecdir}/samba/cups_backend_smb

# Install other stuff
install -d -m 0755 %{buildroot}%{_sysconfdir}/logrotate.d
install -m 0644 %{SOURCE10} %{buildroot}%{_sysconfdir}/logrotate.d/samba

install -m 0644 %{SOURCE11} %{buildroot}%{_sysconfdir}/samba/smb.conf
install -m 0644 %{SOURCE12} %{buildroot}%{_sysconfdir}/samba/smb.conf.example
install -m 0644 %{SOURCE15} %{buildroot}%{_sysconfdir}/samba/usershares.conf

install -d -m 0755 %{buildroot}%{_sysconfdir}/security
install -m 0644 %{SOURCE13} %{buildroot}%{_sysconfdir}/security/pam_winbind.conf

install -d -m 0755 %{buildroot}%{_sysconfdir}/pam.d
install -m 0644 %{SOURCE14} %{buildroot}%{_sysconfdir}/pam.d/samba

echo 127.0.0.1 localhost > %{buildroot}%{_sysconfdir}/samba/lmhosts

# openLDAP database schema
install -d -m 0755 %{buildroot}%{_sysconfdir}/openldap/schema
install -m644 examples/LDAP/samba.schema %{buildroot}%{_sysconfdir}/openldap/schema/samba.schema

install -m 0744 packaging/printing/smbprint %{buildroot}%{_bindir}/smbprint

install -d -m 0755 %{buildroot}%{_tmpfilesdir}
# Create /run/samba.
echo "d /run/samba  755 root root" > %{buildroot}%{_tmpfilesdir}/samba.conf
%if %{with clustering}
echo "d /run/ctdb 755 root root" > %{buildroot}%{_tmpfilesdir}/ctdb.conf
%endif

install -d -m 0755 %{buildroot}%{_sysusersdir}
install -m 0644 %{SOURCE16} %{buildroot}%{_sysusersdir}/samba.conf
install -m 0644 %{SOURCE17} %{buildroot}%{_sysusersdir}/samba-usershares.conf
install -m 0644 %{SOURCE18} %{buildroot}%{_sysusersdir}/samba-winbind.conf

install -d -m 0755 %{buildroot}%{_sysconfdir}/sysconfig
install -m 0644 packaging/systemd/samba.sysconfig %{buildroot}%{_sysconfdir}/sysconfig/samba
%if %{with clustering}
cat > %{buildroot}%{_sysconfdir}/sysconfig/ctdb <<EOF
# CTDB configuration is now in %%{_sysconfdir}/ctdb/ctdb.conf
EOF

install -d -m 0755 %{buildroot}%{_sysconfdir}/ctdb
install -m 0644 ctdb/config/ctdb.conf %{buildroot}%{_sysconfdir}/ctdb/ctdb.conf
install -m 0644 %{SOURCE101} %{buildroot}%{_sysconfdir}/ctdb/script.options
%endif

install -m 0644 %{SOURCE201} packaging/README.downgrade

# NetworkManager online/offline script
install -d -m 0755 %{buildroot}%{_prefix}/lib/NetworkManager/dispatcher.d/
install -m 0755 packaging/NetworkManager/30-winbind-systemd \
            %{buildroot}%{_prefix}/lib/NetworkManager/dispatcher.d/30-winbind

# winbind krb5 plugins
install -d -m 0755 %{buildroot}%{_libdir}/krb5/plugins/libkrb5
touch %{buildroot}%{_libdir}/krb5/plugins/libkrb5/winbind_krb5_locator.so

%if %{without dc} && %{without testsuite}
for i in \
    %{_mandir}/man8/samba.8 \
    %{_mandir}/man8/samba_downgrade_db.8 \
    %{_unitdir}/samba.service \
    ; do
    rm -f %{buildroot}$i
done
%endif

%if %{without gpupdate}
rm -f %{buildroot}%{_sbindir}/samba-gpupdate
rm -f %{buildroot}%{_mandir}/man8/samba-gpupdate.8*
%endif

# This makes the right links, as rpmlint requires that
# the ldconfig-created links be recorded in the RPM.
/sbin/ldconfig -N -n %{buildroot}%{_libdir}

%if %{with testsuite}
rm -f %{buildroot}%{_mandir}/man8/vfs_nfs4acl_xattr.8*
#endif with testsuite
%endif

pushd pidl
%{__make} DESTDIR=%{buildroot} install_vendor

rm -f %{buildroot}%{perl_archlib}/perllocal.pod
rm -f %{buildroot}%{perl_archlib}/vendor_perl/auto/Parse/Pidl/.packlist

# Already packaged by perl Parse:Yapp
rm -rf %{buildroot}%{perl_vendorlib}/Parse/Yapp
popd

%if %{with testsuite}
%check
#
# samba3.smb2.timestamps.*:
#
# The test fails on ext4 as it uses two high-order bits
# in the timestamp so the year 2038 problem is deferred till 2446.
# https://bugzilla.samba.org/show_bug.cgi?id=14546
#
for t in samba3.smb2.timestamps.time_t_15032385535 \
         samba3.smb2.timestamps.time_t_10000000000 \
         samba3.smb2.timestamps.time_t_4294967295 \
         ; do
    echo "^$t" >> selftest/knownfail.d/fedora.%{dist}
done
cat selftest/knownfail.d/fedora.%{dist}

export TDB_NO_FSYNC=1
export NMBD_DONT_LOG_STDOUT=1
export SMBD_DONT_LOG_STDOUT=1
export WINBINDD_DONT_LOG_STDOUT=1
%{__make} %{?_smp_mflags} test FAIL_IMMEDIATELY=1
#endif with testsuite
%endif

%post
%systemd_post smb.service
%systemd_post nmb.service

%preun
%systemd_preun smb.service
%systemd_preun nmb.service

%postun
%systemd_postun_with_restart smb.service
%systemd_postun_with_restart nmb.service

%pre common
# This creates the group 'printadmin'
%sysusers_create_compat %{SOURCE16}

%post common
%{?ldconfig}
%tmpfiles_create %{_tmpfilesdir}/samba.conf
if [ -d /var/cache/samba ]; then
    mv /var/cache/samba/netsamlogon_cache.tdb /var/lib/samba/ 2>/dev/null
    mv /var/cache/samba/winbindd_cache.tdb /var/lib/samba/ 2>/dev/null
    rm -rf /var/cache/samba/
    ln -sf /var/cache/samba /var/lib/samba/
fi

%post client
%{_sbindir}/update-alternatives --install %{_libexecdir}/samba/cups_backend_smb \
    cups_backend_smb \
    %{_bindir}/smbspool 10

%postun client
if [ $1 -eq 0 ] ; then
    %{_sbindir}/update-alternatives --remove cups_backend_smb %{_bindir}/smbspool
fi

%ldconfig_scriptlets client-libs

%ldconfig_scriptlets common-libs

%if %{with dc} || %{with testsuite}
%ldconfig_scriptlets dc-libs

%post dc
%systemd_post samba.service

%preun dc
%systemd_preun samba.service

%postun dc
%systemd_postun_with_restart samba.service
#endif with dc
%endif

%post krb5-printing
%{_sbindir}/update-alternatives --install %{_libexecdir}/samba/cups_backend_smb \
	cups_backend_smb \
	%{_libexecdir}/samba/smbspool_krb5_wrapper 50

%postun krb5-printing
if [ $1 -eq 0 ] ; then
	%{_sbindir}/update-alternatives --remove cups_backend_smb %{_libexecdir}/samba/smbspool_krb5_wrapper
fi

%ldconfig_scriptlets libs

%if %{with libsmbclient}
%ldconfig_scriptlets -n libsmbclient
%endif

%if %{with libwbclient}
%pre -n libwbclient
if [ $1 -gt 1 ] ; then
    rm -rf %{_libdir}/samba/wbclient/ 2>/dev/null
    rm -f /etc/alternatives/libwbclient.so* 2>/dev/null
    rm -f /var/lib/alternatives/libwbclient.so* 2>/dev/null
fi
%{?ldconfig}
#endif {with libwbclient}
%endif

%ldconfig_scriptlets test

%pre usershares
# This creates the group 'usershares'
%sysusers_create_compat %{SOURCE17}

%pre winbind
# This creates the group 'wbpriv'
%sysusers_create_compat %{SOURCE18}

%post winbind
%systemd_post winbind.service

%preun winbind
%systemd_preun winbind.service

%postun winbind
%systemd_postun_with_restart winbind.service

%postun winbind-krb5-locator
if [ "$1" -ge "1" ]; then
        if [ "`readlink %{_sysconfdir}/alternatives/winbind_krb5_locator.so`" == "%{_libdir}/samba/krb5/winbind_krb5_locator.so" ]; then
                %{_sbindir}/update-alternatives --set winbind_krb5_locator.so %{_libdir}/samba/krb5/winbind_krb5_locator.so
        fi
fi

%post winbind-krb5-locator
%{_sbindir}/update-alternatives --install %{_libdir}/krb5/plugins/libkrb5/winbind_krb5_locator.so \
                                winbind_krb5_locator.so %{_libdir}/samba/krb5/winbind_krb5_locator.so 10

%preun winbind-krb5-locator
if [ $1 -eq 0 ]; then
        %{_sbindir}/update-alternatives --remove winbind_krb5_locator.so %{_libdir}/samba/krb5/winbind_krb5_locator.so
fi

%ldconfig_scriptlets winbind-modules

%if %{with clustering}
%post -n ctdb
/usr/bin/systemd-tmpfiles --create %{_tmpfilesdir}/ctdb.conf
%systemd_post ctdb.service

%preun -n ctdb
%systemd_preun ctdb.service

%postun -n ctdb
%systemd_postun_with_restart ctdb.service
%endif


### SAMBA
%files
%license COPYING
%doc README.md WHATSNEW.txt
%doc examples/autofs examples/LDAP examples/misc
%doc examples/printer-accounting examples/printing
%doc packaging/README.downgrade
%{_bindir}/smbstatus
%{_sbindir}/eventlogadm
%{_sbindir}/nmbd
%{_sbindir}/smbd
%if %{with dc} || %{with testsuite}
# This is only used by vfs_dfs_samba4
%{_libdir}/samba/libdfs-server-ad-private-samba.so
%endif
%dir %{_libdir}/samba/auth
%{_libdir}/samba/auth/unix.so
%dir %{_libdir}/samba/vfs
%{_libdir}/samba/vfs/acl_tdb.so
%{_libdir}/samba/vfs/acl_xattr.so
%{_libdir}/samba/vfs/aio_fork.so
%{_libdir}/samba/vfs/aio_pthread.so
%{_libdir}/samba/vfs/audit.so
%{_libdir}/samba/vfs/btrfs.so
%{_libdir}/samba/vfs/cap.so
%{_libdir}/samba/vfs/catia.so
%if %{with vfs_cephfs}
%{_libdir}/samba/vfs/ceph_snapshots.so
%endif
%{_libdir}/samba/vfs/commit.so
%{_libdir}/samba/vfs/crossrename.so
%{_libdir}/samba/vfs/default_quota.so
%if %{with dc} || %{with testsuite}
%{_libdir}/samba/vfs/dfs_samba4.so
%endif
%{_libdir}/samba/vfs/dirsort.so
%{_libdir}/samba/vfs/expand_msdfs.so
%{_libdir}/samba/vfs/extd_audit.so
%{_libdir}/samba/vfs/fake_perms.so
%{_libdir}/samba/vfs/fileid.so
%{_libdir}/samba/vfs/fruit.so
%{_libdir}/samba/vfs/full_audit.so
%{_libdir}/samba/vfs/gpfs.so
%{_libdir}/samba/vfs/glusterfs_fuse.so
%{_libdir}/samba/vfs/linux_xfs_sgid.so
%{_libdir}/samba/vfs/media_harmony.so
%{_libdir}/samba/vfs/offline.so
%{_libdir}/samba/vfs/preopen.so
%{_libdir}/samba/vfs/readahead.so
%{_libdir}/samba/vfs/readonly.so
%{_libdir}/samba/vfs/recycle.so
%{_libdir}/samba/vfs/shadow_copy.so
%{_libdir}/samba/vfs/shadow_copy2.so
%{_libdir}/samba/vfs/shell_snap.so
%{_libdir}/samba/vfs/snapper.so
%{_libdir}/samba/vfs/streams_depot.so
%{_libdir}/samba/vfs/streams_xattr.so
%{_libdir}/samba/vfs/syncops.so
%{_libdir}/samba/vfs/time_audit.so
%{_libdir}/samba/vfs/unityed_media.so
%{_libdir}/samba/vfs/virusfilter.so
%{_libdir}/samba/vfs/widelinks.so
%{_libdir}/samba/vfs/worm.so
%{_libdir}/samba/vfs/xattr_tdb.so

%if %{with testsuite}
%{_libdir}/samba/vfs/nfs4acl_xattr.so
%endif

%dir %{_libexecdir}/samba
%{_libexecdir}/samba/samba-bgqd

%dir %{_datadir}/samba
%dir %{_datadir}/samba/mdssvc
%{_datadir}/samba/mdssvc/elasticsearch_mappings.json

%{_unitdir}/nmb.service
%{_unitdir}/samba-bgqd.service
%{_unitdir}/smb.service
%dir %{_sysconfdir}/openldap/schema
%config %{_sysconfdir}/openldap/schema/samba.schema
%config(noreplace) %{_sysconfdir}/pam.d/samba
%{_mandir}/man1/smbstatus.1*
%{_mandir}/man8/eventlogadm.8*
%{_mandir}/man8/samba-bgqd.8*
%{_mandir}/man8/smbd.8*
%{_mandir}/man8/nmbd.8*
%{_mandir}/man8/vfs_acl_tdb.8*
%{_mandir}/man8/vfs_acl_xattr.8*
%{_mandir}/man8/vfs_aio_fork.8*
%{_mandir}/man8/vfs_aio_pthread.8*
%{_mandir}/man8/vfs_audit.8*
%{_mandir}/man8/vfs_btrfs.8*
%{_mandir}/man8/vfs_cap.8*
%{_mandir}/man8/vfs_catia.8*
%if %{with vfs_cephfs}
%{_mandir}/man8/vfs_ceph_snapshots.8*
%endif
%{_mandir}/man8/vfs_commit.8*
%{_mandir}/man8/vfs_crossrename.8*
%{_mandir}/man8/vfs_default_quota.8*
%{_mandir}/man8/vfs_dirsort.8*
%{_mandir}/man8/vfs_expand_msdfs.8*
%{_mandir}/man8/vfs_extd_audit.8*
%{_mandir}/man8/vfs_fake_perms.8*
%{_mandir}/man8/vfs_fileid.8*
%{_mandir}/man8/vfs_fruit.8*
%{_mandir}/man8/vfs_full_audit.8*
%{_mandir}/man8/vfs_gpfs.8*
%{_mandir}/man8/vfs_glusterfs_fuse.8*
%{_mandir}/man8/vfs_linux_xfs_sgid.8*
%{_mandir}/man8/vfs_media_harmony.8*
%{_mandir}/man8/vfs_offline.8*
%{_mandir}/man8/vfs_preopen.8*
%{_mandir}/man8/vfs_readahead.8*
%{_mandir}/man8/vfs_readonly.8*
%{_mandir}/man8/vfs_recycle.8*
%{_mandir}/man8/vfs_shadow_copy.8*
%{_mandir}/man8/vfs_shadow_copy2.8*
%{_mandir}/man8/vfs_shell_snap.8*
%{_mandir}/man8/vfs_snapper.8*
%{_mandir}/man8/vfs_streams_depot.8*
%{_mandir}/man8/vfs_streams_xattr.8*
%{_mandir}/man8/vfs_syncops.8*
%{_mandir}/man8/vfs_time_audit.8*
%{_mandir}/man8/vfs_unityed_media.8*
%{_mandir}/man8/vfs_virusfilter.8*
%{_mandir}/man8/vfs_widelinks.8*
%{_mandir}/man8/vfs_worm.8*
%{_mandir}/man8/vfs_xattr_tdb.8*

%if %{without vfs_glusterfs}
%exclude %{_mandir}/man8/vfs_glusterfs.8*
%endif

%if %{without vfs_cephfs}
%exclude %{_mandir}/man8/vfs_ceph.8*
%exclude %{_mandir}/man8/vfs_ceph_new.8*
%exclude %{_mandir}/man8/vfs_ceph_snapshots.8*
%endif

%attr(775,root,printadmin) %dir /var/lib/samba/drivers

### CLIENT
%files client
%doc source3/client/README.smbspool
%{_bindir}/cifsdd
%{_bindir}/dbwrap_tool
%{_bindir}/dumpmscat
%{_bindir}/mvxattr
%{_bindir}/mdsearch
%{_bindir}/nmblookup
%{_bindir}/oLschema2ldif
%{_bindir}/regdiff
%{_bindir}/regpatch
%{_bindir}/regshell
%{_bindir}/regtree
%{_bindir}/rpcclient
%{_bindir}/samba-regedit
%{_bindir}/sharesec
%{_bindir}/smbcacls
%{_bindir}/smbclient
%{_bindir}/smbcquotas
%{_bindir}/smbget
%{_bindir}/smbprint
%{_bindir}/smbspool
%{_bindir}/smbtar
%{_bindir}/smbtree
%{_bindir}/wspsearch
%dir %{_libexecdir}/samba
%ghost %{_libexecdir}/samba/cups_backend_smb
%{_mandir}/man1/dbwrap_tool.1*
%{_mandir}/man1/nmblookup.1*
%{_mandir}/man1/oLschema2ldif.1*
%{_mandir}/man1/regdiff.1*
%{_mandir}/man1/regpatch.1*
%{_mandir}/man1/regshell.1*
%{_mandir}/man1/regtree.1*
%{_mandir}/man1/log2pcap.1*
%{_mandir}/man1/mdsearch.1*
%{_mandir}/man1/mvxattr.1*
%{_mandir}/man1/rpcclient.1*
%{_mandir}/man1/sharesec.1*
%{_mandir}/man1/smbcacls.1*
%{_mandir}/man1/smbclient.1*
%{_mandir}/man1/smbcquotas.1*
%{_mandir}/man1/smbget.1*
%{_mandir}/man1/smbtar.1*
%{_mandir}/man1/smbtree.1*
%{_mandir}/man1/wspsearch.1*
%{_mandir}/man7/traffic_learner.7.*
%{_mandir}/man7/traffic_replay.7.*
%{_mandir}/man8/cifsdd.8.*
%{_mandir}/man8/samba-regedit.8*
%{_mandir}/man8/smbspool.8*

%{_bindir}/tdbbackup
%{_bindir}/tdbdump
%{_bindir}/tdbrestore
%{_bindir}/tdbtool
%{_mandir}/man8/tdbbackup.8*
%{_mandir}/man8/tdbdump.8*
%{_mandir}/man8/tdbrestore.8*
%{_mandir}/man8/tdbtool.8*

%{_bindir}/ldbadd
%{_bindir}/ldbdel
%{_bindir}/ldbedit
%{_bindir}/ldbmodify
%{_bindir}/ldbrename
%{_bindir}/ldbsearch
%{_mandir}/man1/ldbadd.1.gz
%{_mandir}/man1/ldbdel.1.gz
%{_mandir}/man1/ldbedit.1.gz
%{_mandir}/man1/ldbmodify.1.gz
%{_mandir}/man1/ldbrename.1.gz
%{_mandir}/man1/ldbsearch.1.gz

### CLIENT-LIBS
%files client-libs
%{_libdir}/libdcerpc-binding.so.*
%{_libdir}/libdcerpc-server-core.so.*
%{_libdir}/libndr.so.*
%{_libdir}/libndr-krb5pac.so.*
%{_libdir}/libndr-nbt.so.*
%{_libdir}/libndr-standard.so.*
%{_libdir}/libsamba-errors.so.*
%{_libdir}/libsamba-passdb.so.*
%{_libdir}/libsamba-util.so.*
%{_libdir}/libsmbconf.so.*
%{_libdir}/libsmbldap.so.*

%dir %{_libdir}/samba
%{_libdir}/samba/libCHARSET3-private-samba.so
%{_libdir}/samba/libMESSAGING-SEND-private-samba.so
%{_libdir}/samba/libMESSAGING-private-samba.so
%{_libdir}/samba/libaddns-private-samba.so
%{_libdir}/samba/libads-private-samba.so
%{_libdir}/samba/libasn1util-private-samba.so
%{_libdir}/samba/libauth-private-samba.so
%{_libdir}/samba/libauthkrb5-private-samba.so
%{_libdir}/samba/libcli-cldap-private-samba.so
%{_libdir}/samba/libcli-ldap-common-private-samba.so
%{_libdir}/samba/libcli-ldap-private-samba.so
%{_libdir}/samba/libcli-nbt-private-samba.so
%{_libdir}/samba/libcli-smb-common-private-samba.so
%{_libdir}/samba/libcli-spoolss-private-samba.so
%{_libdir}/samba/libcliauth-private-samba.so
%{_libdir}/samba/libclidns-private-samba.so
%{_libdir}/samba/libcluster-private-samba.so
%{_libdir}/samba/libcmdline-contexts-private-samba.so
%{_libdir}/samba/libcommon-auth-private-samba.so
%{_libdir}/samba/libctdb-event-client-private-samba.so
%{_libdir}/samba/libdbwrap-private-samba.so
%{_libdir}/samba/libdcerpc-pkt-auth-private-samba.so
%{_libdir}/samba/libdcerpc-private-samba.so
%{_libdir}/samba/libdcerpc-samba-private-samba.so
%{_libdir}/samba/libevents-private-samba.so
%{_libdir}/samba/libflag-mapping-private-samba.so
%{_libdir}/samba/libgenrand-private-samba.so
%{_libdir}/samba/libgensec-private-samba.so
%{_libdir}/samba/libgpext-private-samba.so
%{_libdir}/samba/libgpo-private-samba.so
%{_libdir}/samba/libgse-private-samba.so
%{_libdir}/samba/libhttp-private-samba.so
%{_libdir}/samba/libinterfaces-private-samba.so
%{_libdir}/samba/libiov-buf-private-samba.so
%{_libdir}/samba/libkrb5samba-private-samba.so
%{_libdir}/samba/libldbsamba-private-samba.so
%{_libdir}/samba/liblibcli-lsa3-private-samba.so
%{_libdir}/samba/liblibcli-netlogon3-private-samba.so
%{_libdir}/samba/liblibsmb-private-samba.so
%{_libdir}/samba/libmessages-dgm-private-samba.so
%{_libdir}/samba/libmessages-util-private-samba.so
%{_libdir}/samba/libmscat-private-samba.so
%{_libdir}/samba/libmsghdr-private-samba.so
%{_libdir}/samba/libmsrpc3-private-samba.so
%{_libdir}/samba/libndr-samba-private-samba.so
%{_libdir}/samba/libndr-samba4-private-samba.so
%{_libdir}/samba/libnet-keytab-private-samba.so
%{_libdir}/samba/libnetif-private-samba.so
%{_libdir}/samba/libnpa-tstream-private-samba.so
%{_libdir}/samba/libposix-eadb-private-samba.so
%{_libdir}/samba/libprinter-driver-private-samba.so
%{_libdir}/samba/libprinting-migrate-private-samba.so
%{_libdir}/samba/libreplace-private-samba.so
%{_libdir}/samba/libregistry-private-samba.so
%{_libdir}/samba/libsamba-cluster-support-private-samba.so
%{_libdir}/samba/libsamba-credentials-private-samba.so
%{_libdir}/samba/libsamba-debug-private-samba.so
%{_libdir}/samba/libsamba-hostconfig-private-samba.so
%{_libdir}/samba/libsamba-modules-private-samba.so
%{_libdir}/samba/libsamba-net-private-samba.so
%{_libdir}/samba/libsamba-policy-private-samba.so
%{_libdir}/samba/libsamba-security-private-samba.so
%{_libdir}/samba/libsamba-sockets-private-samba.so
%{_libdir}/samba/libsamba3-util-private-samba.so
%{_libdir}/samba/libsamdb-common-private-samba.so
%{_libdir}/samba/libsamdb-private-samba.so
%{_libdir}/samba/libsecrets3-private-samba.so
%{_libdir}/samba/libserver-id-db-private-samba.so
%{_libdir}/samba/libserver-role-private-samba.so
%{_libdir}/samba/libsmb-transport-private-samba.so
%{_libdir}/samba/libsmbclient-raw-private-samba.so
%{_libdir}/samba/libsmbd-base-private-samba.so
%{_libdir}/samba/libsmbd-shim-private-samba.so
%{_libdir}/samba/libsmbldaphelper-private-samba.so
%{_libdir}/samba/libstable-sort-private-samba.so
%{_libdir}/samba/libsys-rw-private-samba.so
%{_libdir}/samba/libsocket-blocking-private-samba.so
%{_libdir}/samba/libtime-basic-private-samba.so
%{_libdir}/samba/libtorture-private-samba.so
%{_libdir}/samba/libutil-crypt-private-samba.so
%{_libdir}/samba/libutil-reg-private-samba.so
%{_libdir}/samba/libutil-setid-private-samba.so
%{_libdir}/samba/libutil-tdb-private-samba.so

%if %{without libwbclient}
%{_libdir}/samba/libwbclient.so.*
#endif without libwbclient
%endif

%if %{without libsmbclient}
%{_libdir}/samba/libsmbclient.so.*
%{_mandir}/man7/libsmbclient.7*
#endif without libsmbclient
%endif

%{_libdir}/samba/libtalloc-*.so
%{_libdir}/samba/libtevent-*.so
%{_libdir}/samba/libtdb-*.so
%{_libdir}/samba/libldb-*.so

%{_libdir}/samba/ldb/asq.so
%{_libdir}/samba/ldb/ldb.so
%{_libdir}/samba/ldb/mdb.so
%{_libdir}/samba/ldb/paged_searches.so
%{_libdir}/samba/ldb/rdn_name.so
%{_libdir}/samba/ldb/sample.so
%{_libdir}/samba/ldb/server_sort.so
%{_libdir}/samba/ldb/skel.so
%{_libdir}/samba/ldb/tdb.so

%{_mandir}/man3/ldb.3.gz
%{_mandir}/man3/talloc.3.gz

### COMMON
%files common
%{_tmpfilesdir}/samba.conf
%{_sysusersdir}/samba.conf
%dir %{_sysconfdir}/logrotate.d/
%config(noreplace) %{_sysconfdir}/logrotate.d/samba
%attr(0700,root,root) %dir /var/log/samba
%attr(0700,root,root) %dir /var/log/samba/old
%ghost %dir /run/samba
%ghost %dir /run/winbindd
%dir /var/lib/samba
%attr(700,root,root) %dir /var/lib/samba/private
%dir /var/lib/samba/lock
%attr(755,root,root) %dir %{_sysconfdir}/samba
%config(noreplace) %{_sysconfdir}/samba/smb.conf
%{_sysconfdir}/samba/smb.conf.example
%config(noreplace) %{_sysconfdir}/samba/lmhosts
%config(noreplace) %{_sysconfdir}/sysconfig/samba
%{_mandir}/man5/lmhosts.5*
%{_mandir}/man5/smb.conf.5*
%{_mandir}/man5/smbpasswd.5*
%{_mandir}/man7/samba.7*

### COMMON-LIBS
%files common-libs
# common libraries
%{_libdir}/samba/libcmdline-private-samba.so

%dir %{_libdir}/samba/ldb

%dir %{_libdir}/samba/pdb
%{_libdir}/samba/pdb/ldapsam.so
%{_libdir}/samba/pdb/smbpasswd.so
%{_libdir}/samba/pdb/tdbsam.so

### COMMON-TOOLS
%files common-tools
%{_bindir}/net
%{_bindir}/pdbedit
%{_bindir}/profiles
%{_bindir}/samba-log-parser
%{_bindir}/smbcontrol
%{_bindir}/smbpasswd
%{_bindir}/testparm
%{_mandir}/man1/profiles.1*
%{_mandir}/man1/samba-log-parser.1*
%{_mandir}/man1/smbcontrol.1*
%{_mandir}/man1/testparm.1*
%{_mandir}/man8/net.8*
%{_mandir}/man8/pdbedit.8*
%{_mandir}/man8/smbpasswd.8*

### TOOLS
%files tools
%{_bindir}/samba-tool
%{_mandir}/man8/samba-tool.8*

### RPC
%files dcerpc
%dir %{_libexecdir}/samba
%{_libexecdir}/samba/samba-dcerpcd
%{_libexecdir}/samba/rpcd_classic
%{_libexecdir}/samba/rpcd_epmapper
%{_libexecdir}/samba/rpcd_fsrvp
%{_libexecdir}/samba/rpcd_lsad
%{_libexecdir}/samba/rpcd_mdssvc
%if %{with testsuite}
%{_libexecdir}/samba/rpcd_rpcecho
%endif
%{_libexecdir}/samba/rpcd_spoolss
%{_libexecdir}/samba/rpcd_winreg
%{_libexecdir}/samba/rpcd_witness
%{_mandir}/man8/samba-dcerpcd.8*

### DC
%if %{with dc} || %{with testsuite}
%files dc
%{_unitdir}/samba.service
%{_sbindir}/samba
%{_sbindir}/samba_dnsupdate
%{_sbindir}/samba_downgrade_db
%{_sbindir}/samba_kcc
%{_sbindir}/samba_spnupdate
%{_sbindir}/samba_upgradedns

%{_libdir}/krb5/plugins/kdb/samba.so

%{_libdir}/samba/auth/samba4.so
%dir %{_libdir}/samba/gensec
%{_libdir}/samba/gensec/krb5.so
%{_libdir}/samba/ldb/acl.so
%{_libdir}/samba/ldb/aclread.so
%{_libdir}/samba/ldb/anr.so
%{_libdir}/samba/ldb/audit_log.so
%{_libdir}/samba/ldb/count_attrs.so
%{_libdir}/samba/ldb/descriptor.so
%{_libdir}/samba/ldb/dirsync.so
%{_libdir}/samba/ldb/dns_notify.so
%{_libdir}/samba/ldb/dsdb_notification.so
%{_libdir}/samba/ldb/encrypted_secrets.so
%{_libdir}/samba/ldb/extended_dn_in.so
%{_libdir}/samba/ldb/extended_dn_out.so
%{_libdir}/samba/ldb/extended_dn_store.so
%{_libdir}/samba/ldb/group_audit_log.so
%{_libdir}/samba/ldb/instancetype.so
%{_libdir}/samba/ldb/lazy_commit.so
%{_libdir}/samba/ldb/linked_attributes.so
%{_libdir}/samba/ldb/new_partition.so
%{_libdir}/samba/ldb/objectclass.so
%{_libdir}/samba/ldb/objectclass_attrs.so
%{_libdir}/samba/ldb/objectguid.so
%{_libdir}/samba/ldb/operational.so
%{_libdir}/samba/ldb/paged_results.so
%{_libdir}/samba/ldb/partition.so
%{_libdir}/samba/ldb/password_hash.so
%{_libdir}/samba/ldb/ranged_results.so
%{_libdir}/samba/ldb/repl_meta_data.so
%{_libdir}/samba/ldb/resolve_oids.so
%{_libdir}/samba/ldb/rootdse.so
%{_libdir}/samba/ldb/samba3sam.so
%{_libdir}/samba/ldb/samba3sid.so
%{_libdir}/samba/ldb/samba_dsdb.so
%{_libdir}/samba/ldb/samba_secrets.so
%{_libdir}/samba/ldb/samldb.so
%{_libdir}/samba/ldb/schema_data.so
%{_libdir}/samba/ldb/schema_load.so
%{_libdir}/samba/ldb/secrets_tdb_sync.so
%{_libdir}/samba/ldb/show_deleted.so
%{_libdir}/samba/ldb/subtree_delete.so
%{_libdir}/samba/ldb/subtree_rename.so
%{_libdir}/samba/ldb/tombstone_reanimate.so
%{_libdir}/samba/ldb/unique_object_sids.so
%{_libdir}/samba/ldb/update_keytab.so
%{_libdir}/samba/ldb/vlv.so
%{_libdir}/samba/ldb/wins_ldb.so

%{_libdir}/samba/vfs/posix_eadb.so
%dir /var/lib/samba/sysvol
%{_mandir}/man8/samba.8*
%{_mandir}/man8/samba_downgrade_db.8*
%dir %{_datadir}/samba/admx
%{_datadir}/samba/admx/GNOME_Settings.admx
%{_datadir}/samba/admx/samba.admx
%dir %{_datadir}/samba/admx/en-US
%{_datadir}/samba/admx/en-US/GNOME_Settings.adml
%{_datadir}/samba/admx/en-US/samba.adml
%dir %{_datadir}/samba/admx/ru-RU
%{_datadir}/samba/admx/ru-RU/GNOME_Settings.adml

%files dc-provision
%license source4/setup/ad-schema/licence.txt
%{_datadir}/samba/setup

#endif with dc || with testsuite
%endif
### DC-LIBS
%files dc-libs
%{_libdir}/samba/libauth4-private-samba.so

%if %{with dc} || %{with testsuite}
%{_libdir}/samba/libdb-glue-private-samba.so
%{_libdir}/samba/libpac-private-samba.so
%{_libdir}/samba/libprocess-model-private-samba.so
%{_libdir}/samba/libservice-private-samba.so

%if %{with testsuite}
%{_libdir}/samba/libntvfs-private-samba.so
%endif

%dir %{_libdir}/samba/process_model
%{_libdir}/samba/process_model/prefork.so
%{_libdir}/samba/process_model/standard.so
%dir %{_libdir}/samba/service
%{_libdir}/samba/service/cldap.so
%{_libdir}/samba/service/dcerpc.so
%{_libdir}/samba/service/dns.so
%{_libdir}/samba/service/dns_update.so
%{_libdir}/samba/service/drepl.so
%{_libdir}/samba/service/kcc.so
%{_libdir}/samba/service/kdc.so
%{_libdir}/samba/service/ldap.so
%{_libdir}/samba/service/nbtd.so
%{_libdir}/samba/service/ntp_signd.so
%{_libdir}/samba/service/s3fs.so
%{_libdir}/samba/service/winbindd.so
%{_libdir}/samba/service/wrepl.so

%if %{with testsuite}
%{_libdir}/samba/service/smb.so
%endif

%{_libdir}/samba/libdcerpc-server-private-samba.so
%{_libdir}/samba/libad-claims-private-samba.so
%{_libdir}/samba/libauthn-policy-util-private-samba.so
%{_libdir}/samba/libdsdb-module-private-samba.so
%{_libdir}/samba/libdsdb-garbage-collect-tombstones-private-samba.so
%{_libdir}/samba/libscavenge-dns-records-private-samba.so

### DC-BIND
%files dc-bind-dlz
%attr(770,root,named) %dir /var/lib/samba/bind-dns
%dir %{_libdir}/samba/bind9
%{_libdir}/samba/bind9/dlz_bind9_10.so
%{_libdir}/samba/bind9/dlz_bind9_11.so
%{_libdir}/samba/bind9/dlz_bind9_12.so
%{_libdir}/samba/bind9/dlz_bind9_14.so
%{_libdir}/samba/bind9/dlz_bind9_16.so
%{_libdir}/samba/bind9/dlz_bind9_18.so
#endif with dc
%endif

### DEVEL
%files devel
%{_includedir}/samba-4.0/charset.h
%{_includedir}/samba-4.0/core/doserr.h
%{_includedir}/samba-4.0/core/error.h
%{_includedir}/samba-4.0/core/hresult.h
%{_includedir}/samba-4.0/core/ntstatus.h
%{_includedir}/samba-4.0/core/ntstatus_gen.h
%{_includedir}/samba-4.0/core/werror.h
%{_includedir}/samba-4.0/core/werror_gen.h
%{_includedir}/samba-4.0/dcesrv_core.h
%{_includedir}/samba-4.0/domain_credentials.h
%{_includedir}/samba-4.0/gen_ndr/atsvc.h
%{_includedir}/samba-4.0/gen_ndr/auth.h
%{_includedir}/samba-4.0/gen_ndr/claims.h
%{_includedir}/samba-4.0/gen_ndr/dcerpc.h
%{_includedir}/samba-4.0/gen_ndr/krb5pac.h
%{_includedir}/samba-4.0/gen_ndr/lsa.h
%{_includedir}/samba-4.0/gen_ndr/misc.h
%{_includedir}/samba-4.0/gen_ndr/nbt.h
%{_includedir}/samba-4.0/gen_ndr/drsblobs.h
%{_includedir}/samba-4.0/gen_ndr/drsuapi.h
%{_includedir}/samba-4.0/gen_ndr/ndr_drsblobs.h
%{_includedir}/samba-4.0/gen_ndr/ndr_drsuapi.h
%{_includedir}/samba-4.0/gen_ndr/ndr_atsvc.h
%{_includedir}/samba-4.0/gen_ndr/ndr_dcerpc.h
%{_includedir}/samba-4.0/gen_ndr/ndr_krb5pac.h
%{_includedir}/samba-4.0/gen_ndr/ndr_misc.h
%{_includedir}/samba-4.0/gen_ndr/ndr_nbt.h
%{_includedir}/samba-4.0/gen_ndr/ndr_samr.h
%{_includedir}/samba-4.0/gen_ndr/ndr_svcctl.h
%{_includedir}/samba-4.0/gen_ndr/ndr_svcctl_c.h
%{_includedir}/samba-4.0/gen_ndr/netlogon.h
%{_includedir}/samba-4.0/gen_ndr/samr.h
%{_includedir}/samba-4.0/gen_ndr/security.h
%{_includedir}/samba-4.0/gen_ndr/server_id.h
%{_includedir}/samba-4.0/gen_ndr/svcctl.h
%{_includedir}/samba-4.0/ldb_wrap.h
%{_includedir}/samba-4.0/lookup_sid.h
%{_includedir}/samba-4.0/machine_sid.h
%{_includedir}/samba-4.0/ndr.h
%dir %{_includedir}/samba-4.0/ndr
%{_includedir}/samba-4.0/ndr/ndr_dcerpc.h
%{_includedir}/samba-4.0/ndr/ndr_drsblobs.h
%{_includedir}/samba-4.0/ndr/ndr_drsuapi.h
%{_includedir}/samba-4.0/ndr/ndr_krb5pac.h
%{_includedir}/samba-4.0/ndr/ndr_svcctl.h
%{_includedir}/samba-4.0/ndr/ndr_nbt.h
%{_includedir}/samba-4.0/passdb.h
%{_includedir}/samba-4.0/rpc_common.h
%{_includedir}/samba-4.0/samba/session.h
%{_includedir}/samba-4.0/samba/version.h
%{_includedir}/samba-4.0/share.h
%{_includedir}/samba-4.0/smb2_lease_struct.h
%{_includedir}/samba-4.0/smb3posix.h
%{_includedir}/samba-4.0/smbconf.h
%{_includedir}/samba-4.0/smb_ldap.h
%{_includedir}/samba-4.0/smbldap.h
%{_includedir}/samba-4.0/tdr.h
%{_includedir}/samba-4.0/tsocket.h
%{_includedir}/samba-4.0/tsocket_internal.h
%dir %{_includedir}/samba-4.0/util
%{_includedir}/samba-4.0/util/attr.h
%{_includedir}/samba-4.0/util/blocking.h
%{_includedir}/samba-4.0/util/data_blob.h
%{_includedir}/samba-4.0/util/debug.h
%{_includedir}/samba-4.0/util/discard.h
%{_includedir}/samba-4.0/util/fault.h
%{_includedir}/samba-4.0/util/genrand.h
%{_includedir}/samba-4.0/util/idtree.h
%{_includedir}/samba-4.0/util/idtree_random.h
%{_includedir}/samba-4.0/util/signal.h
%{_includedir}/samba-4.0/util/substitute.h
%{_includedir}/samba-4.0/util/time.h
%{_includedir}/samba-4.0/util/tfork.h
%{_includedir}/samba-4.0/util_ldb.h
%{_libdir}/libdcerpc-binding.so
%{_libdir}/libndr-krb5pac.so
%{_libdir}/libndr-nbt.so
%{_libdir}/libndr-standard.so
%{_libdir}/libndr.so
%{_libdir}/libsamba-errors.so
%{_libdir}/libsamba-util.so
%{_libdir}/libsmbconf.so
%{_libdir}/pkgconfig/ndr.pc
%{_libdir}/pkgconfig/ndr_krb5pac.pc
%{_libdir}/pkgconfig/ndr_nbt.pc
%{_libdir}/pkgconfig/ndr_standard.pc
%{_libdir}/pkgconfig/samba-util.pc
%{_libdir}/libsamba-passdb.so
%{_libdir}/libsmbldap.so

%{_libdir}/libdcerpc-server-core.so

%if %{without libsmbclient}
%{_includedir}/samba-4.0/libsmbclient.h
#endif without libsmbclient
%endif

%if %{without libwbclient}
%{_includedir}/samba-4.0/wbclient.h
#endif without libwbclient
%endif

### VFS-CEPHFS
%if %{with vfs_cephfs}
%files vfs-cephfs
%{_libdir}/samba/vfs/ceph.so
%{_libdir}/samba/vfs/ceph_new.so
%{_mandir}/man8/vfs_ceph.8*
%{_mandir}/man8/vfs_ceph_new.8*
%endif

### VFS-IOURING
%if %{with vfs_io_uring}
%files vfs-iouring
%{_libdir}/samba/vfs/io_uring.so
%{_mandir}/man8/vfs_io_uring.8*
%endif

### VFS-GLUSTERFS
%if %{with vfs_glusterfs}
%files vfs-glusterfs
%{_libdir}/samba/vfs/glusterfs.so
%{_mandir}/man8/vfs_glusterfs.8*
%endif

### GPUPDATE
%if %{with gpupdate}
%files gpupdate
%{_mandir}/man8/samba-gpupdate.8*
%{_sbindir}/samba-gpupdate
#endif with gpupdate
%endif

### KRB5-PRINTING
%files krb5-printing
%attr(0700,root,root) %{_libexecdir}/samba/smbspool_krb5_wrapper
%{_mandir}/man8/smbspool_krb5_wrapper.8*

### LDB-LDAP-MODULES
%files ldb-ldap-modules
%{_libdir}/samba/ldb/ldbsamba_extensions.so
%{_libdir}/samba/ldb/ildap.so
%{_libdir}/samba/ldb/ldap.so

### LIBS
%files libs
%{_libdir}/samba/libLIBWBCLIENT-OLD-private-samba.so
%{_libdir}/samba/libauth-unix-token-private-samba.so
%{_libdir}/samba/libdcerpc-samba4-private-samba.so
%{_libdir}/samba/libdcerpc-samr-private-samba.so
%{_libdir}/samba/libdnsserver-common-private-samba.so
%{_libdir}/samba/libshares-private-samba.so
%{_libdir}/samba/libsmbpasswdparser-private-samba.so
%{_libdir}/samba/libxattr-tdb-private-samba.so
%{_libdir}/samba/libREG-FULL-private-samba.so
%{_libdir}/samba/libRPC-SERVER-LOOP-private-samba.so
%{_libdir}/samba/libRPC-WORKER-private-samba.so

### LIBNETAPI
%files -n libnetapi
%{_libdir}/libnetapi.so.*

### LIBNETAPI-DEVEL
%files -n libnetapi-devel
%{_includedir}/samba-4.0/netapi.h
%{_libdir}/libnetapi.so
%{_libdir}/pkgconfig/netapi.pc

### LIBSMBCLIENT
%if %{with libsmbclient}
%files -n libsmbclient
%{_libdir}/libsmbclient.so.*

### LIBSMBCLIENT-DEVEL
%files -n libsmbclient-devel
%{_includedir}/samba-4.0/libsmbclient.h
%{_libdir}/libsmbclient.so
%{_libdir}/pkgconfig/smbclient.pc
%{_mandir}/man7/libsmbclient.7*
#endif {with libsmbclient}
%endif

### LIBWBCLIENT
%if %{with libwbclient}
%files -n libwbclient
%{_libdir}/libwbclient.so.*

### LIBWBCLIENT-DEVEL
%files -n libwbclient-devel
%{_includedir}/samba-4.0/wbclient.h
%{_libdir}/libwbclient.so
%{_libdir}/pkgconfig/wbclient.pc
#endif {with libwbclient}
%endif

### PIDL
%files pidl
%doc pidl/README
%attr(755,root,root) %{_bindir}/pidl
%dir %{perl_vendorlib}/Parse
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl.pm
%dir %{perl_vendorlib}/Parse/Pidl
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Base.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/CUtil.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Samba4.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Expr.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/ODL.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Typelist.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/IDL.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Compat.pm
%dir %{perl_vendorlib}/Parse/Pidl/Wireshark
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Wireshark/Conformance.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Wireshark/NDR.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Dump.pm
%dir %{perl_vendorlib}/Parse/Pidl/Samba3
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Samba3/ServerNDR.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Samba3/ClientNDR.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Samba3/Template.pm
%dir %{perl_vendorlib}/Parse/Pidl/Samba4
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Samba4/Header.pm
%dir %{perl_vendorlib}/Parse/Pidl/Samba4/COM
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Samba4/COM/Header.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Samba4/COM/Proxy.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Samba4/COM/Stub.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Samba4/Python.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Samba4/Template.pm
%dir %{perl_vendorlib}/Parse/Pidl/Samba4/NDR
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Samba4/NDR/Server.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Samba4/NDR/ServerCompat.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Samba4/NDR/Client.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Samba4/NDR/Parser.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Samba4/TDR.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/NDR.pm
%attr(644,root,root) %{perl_vendorlib}/Parse/Pidl/Util.pm
%attr(644,root,root) %{_mandir}/man1/pidl.1*
%attr(644,root,root) %{_mandir}/man3/Parse::Pidl::Dump.3pm*
%attr(644,root,root) %{_mandir}/man3/Parse::Pidl::NDR.3pm*
%attr(644,root,root) %{_mandir}/man3/Parse::Pidl::Util.3pm*
%attr(644,root,root) %{_mandir}/man3/Parse::Pidl::Wireshark::Conformance.3pm*
%attr(644,root,root) %{_mandir}/man3/Parse::Pidl::Wireshark::NDR.3pm*

### PYTHON3
%files -n python3-%{name}
%dir %{python3_sitearch}/samba/
%{python3_sitearch}/samba/*.py
%dir %{python3_sitearch}/samba/__pycache__
%{python3_sitearch}/samba/__pycache__/*.*.pyc
%{python3_sitearch}/samba/*.*.so

%dir %{python3_sitearch}/samba/dcerpc
%dir %{python3_sitearch}/samba/dcerpc/__pycache__
%{python3_sitearch}/samba/dcerpc/__pycache__/*.*.pyc
%{python3_sitearch}/samba/dcerpc/*.py
%{python3_sitearch}/samba/dcerpc/*.*.so

%dir %{python3_sitearch}/samba/domain
%{python3_sitearch}/samba/domain/*.py
%dir %{python3_sitearch}/samba/domain/__pycache__
%{python3_sitearch}/samba/domain/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/domain/models
%{python3_sitearch}/samba/domain/models/*.py
%dir %{python3_sitearch}/samba/domain/models/__pycache__
%{python3_sitearch}/samba/domain/models/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/emulate
%dir %{python3_sitearch}/samba/emulate/__pycache__
%{python3_sitearch}/samba/emulate/__pycache__/*.*.pyc
%{python3_sitearch}/samba/emulate/*.py

%dir %{python3_sitearch}/samba/gp
%{python3_sitearch}/samba/gp/*.py
%dir %{python3_sitearch}/samba/gp/__pycache__
%{python3_sitearch}/samba/gp/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/gp/util
%{python3_sitearch}/samba/gp/util/*.py
%dir %{python3_sitearch}/samba/gp/util/__pycache__
%{python3_sitearch}/samba/gp/util/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/gp_parse
%{python3_sitearch}/samba/gp_parse/*.py
%dir %{python3_sitearch}/samba/gp_parse/__pycache__
%{python3_sitearch}/samba/gp_parse/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/netcmd
%{python3_sitearch}/samba/netcmd/*.py
%dir %{python3_sitearch}/samba/netcmd/__pycache__
%{python3_sitearch}/samba/netcmd/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/netcmd/domain
%{python3_sitearch}/samba/netcmd/domain/*.py
%dir %{python3_sitearch}/samba/netcmd/domain/__pycache__
%{python3_sitearch}/samba/netcmd/domain/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/netcmd/domain/auth
%{python3_sitearch}/samba/netcmd/domain/auth/*.py
%dir %{python3_sitearch}/samba/netcmd/domain/auth/__pycache__
%{python3_sitearch}/samba/netcmd/domain/auth/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/netcmd/domain/auth/policy
%{python3_sitearch}/samba/netcmd/domain/auth/policy/*.py
%dir %{python3_sitearch}/samba/netcmd/domain/auth/policy/__pycache__
%{python3_sitearch}/samba/netcmd/domain/auth/policy/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/netcmd/domain/auth/silo
%{python3_sitearch}/samba/netcmd/domain/auth/silo/*.py
%dir %{python3_sitearch}/samba/netcmd/domain/auth/silo/__pycache__
%{python3_sitearch}/samba/netcmd/domain/auth/silo/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/netcmd/domain/claim
%{python3_sitearch}/samba/netcmd/domain/claim/*.py
%dir %{python3_sitearch}/samba/netcmd/domain/claim/__pycache__
%{python3_sitearch}/samba/netcmd/domain/claim/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/netcmd/domain/kds
%{python3_sitearch}/samba/netcmd/domain/kds/*.py
%dir %{python3_sitearch}/samba/netcmd/domain/kds/__pycache__
%{python3_sitearch}/samba/netcmd/domain/kds/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/netcmd/service_account
%{python3_sitearch}/samba/netcmd/service_account/*.py
%dir %{python3_sitearch}/samba/netcmd/service_account/__pycache__
%{python3_sitearch}/samba/netcmd/service_account/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/netcmd/user
%{python3_sitearch}/samba/netcmd/user/*.py
%dir %{python3_sitearch}/samba/netcmd/user/__pycache__
%{python3_sitearch}/samba/netcmd/user/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/netcmd/user/auth
%{python3_sitearch}/samba/netcmd/user/auth/*.py
%dir %{python3_sitearch}/samba/netcmd/user/auth/__pycache__
%{python3_sitearch}/samba/netcmd/user/auth/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/netcmd/user/readpasswords
%{python3_sitearch}/samba/netcmd/user/readpasswords/*.py
%dir %{python3_sitearch}/samba/netcmd/user/readpasswords/__pycache__
%{python3_sitearch}/samba/netcmd/user/readpasswords/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/samba3
%{python3_sitearch}/samba/samba3/*.py
%dir %{python3_sitearch}/samba/samba3/__pycache__
%{python3_sitearch}/samba/samba3/__pycache__/*.*.pyc
%{python3_sitearch}/samba/samba3/*.*.so

%dir %{python3_sitearch}/samba/subunit
%{python3_sitearch}/samba/subunit/*.py
%dir %{python3_sitearch}/samba/subunit/__pycache__
%{python3_sitearch}/samba/subunit/__pycache__/*.*.pyc

%{_libdir}/samba/libsamba-net-join.*-private-samba.so
%{_libdir}/samba/libsamba-python.*-private-samba.so

%{_libdir}/samba/libpyldb-util.cpython*.so
%{_libdir}/samba/libpytalloc-util.cpython*.so

%{python3_sitearch}/talloc.*.so*
%{python3_sitearch}/__pycache__/tevent.*.pyc
%{python3_sitearch}/_tevent.*.so*
%{python3_sitearch}/tevent.py*
%{python3_sitearch}/__pycache__/_tdb_text.*.pyc
%{python3_sitearch}/_tdb_text.py*
%{python3_sitearch}/tdb.*.so
%{python3_sitearch}/__pycache__/_ldb_text.*.pyc
%{python3_sitearch}/_ldb_text.py*
%{python3_sitearch}/ldb.*.so

%files -n python3-%{name}-dc
%{python3_sitearch}/samba/samdb.py
%{python3_sitearch}/samba/schema.py

%{python3_sitearch}/samba/__pycache__/domain_update.*.pyc
%{python3_sitearch}/samba/__pycache__/dnsserver.*.pyc
%{python3_sitearch}/samba/__pycache__/forest_update.*.pyc
%{python3_sitearch}/samba/__pycache__/ms_forest_updates_markdown.*.pyc
%{python3_sitearch}/samba/__pycache__/ms_schema_markdown.*.pyc
%{python3_sitearch}/samba/__pycache__/remove_dc.*.pyc
%{python3_sitearch}/samba/__pycache__/samdb.*.pyc
%{python3_sitearch}/samba/__pycache__/schema.*.pyc
%{python3_sitearch}/samba/__pycache__/uptodateness.*.pyc
%{python3_sitearch}/samba/dcerpc/dnsserver.*.so
%if %{with dc} || %{with testsuite}
%{python3_sitearch}/samba/dckeytab.*.so
%endif
%{python3_sitearch}/samba/domain_update.py
%{python3_sitearch}/samba/forest_update.py
%{python3_sitearch}/samba/ms_forest_updates_markdown.py
%{python3_sitearch}/samba/ms_schema_markdown.py

%dir %{python3_sitearch}/samba/kcc
%{python3_sitearch}/samba/kcc/__init__.py
%{python3_sitearch}/samba/kcc/debug.py
%{python3_sitearch}/samba/kcc/graph.py
%{python3_sitearch}/samba/kcc/graph_utils.py
%{python3_sitearch}/samba/kcc/kcc_utils.py
%{python3_sitearch}/samba/kcc/ldif_import_export.py
%{python3_sitearch}/samba/dnsserver.py

%dir %{python3_sitearch}/samba/kcc/__pycache__
%{python3_sitearch}/samba/kcc/__pycache__/__init__.*.pyc
%{python3_sitearch}/samba/kcc/__pycache__/debug.*.pyc
%{python3_sitearch}/samba/kcc/__pycache__/graph.*.pyc
%{python3_sitearch}/samba/kcc/__pycache__/graph_utils.*.pyc
%{python3_sitearch}/samba/kcc/__pycache__/kcc_utils.*.pyc
%{python3_sitearch}/samba/kcc/__pycache__/ldif_import_export.*.pyc

%dir %{python3_sitearch}/samba/provision
%{python3_sitearch}/samba/provision/backend.py
%{python3_sitearch}/samba/provision/common.py
%{python3_sitearch}/samba/provision/kerberos.py
%{python3_sitearch}/samba/provision/kerberos_implementation.py
%{python3_sitearch}/samba/provision/sambadns.py

%dir %{python3_sitearch}/samba/provision/__pycache__
%{python3_sitearch}/samba/provision/__init__.py
%{python3_sitearch}/samba/provision/__pycache__/__init__.*.pyc
%{python3_sitearch}/samba/provision/__pycache__/backend.*.pyc
%{python3_sitearch}/samba/provision/__pycache__/common.*.pyc
%{python3_sitearch}/samba/provision/__pycache__/kerberos.*.pyc
%{python3_sitearch}/samba/provision/__pycache__/kerberos_implementation.*.pyc
%{python3_sitearch}/samba/provision/__pycache__/sambadns.*.pyc

%{python3_sitearch}/samba/remove_dc.py
%{python3_sitearch}/samba/uptodateness.py

%files -n python3-%{name}-test
%dir %{python3_sitearch}/samba/tests
%{python3_sitearch}/samba/tests/*.py
%dir %{python3_sitearch}/samba/tests/__pycache__
%{python3_sitearch}/samba/tests/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/tests/blackbox
%{python3_sitearch}/samba/tests/blackbox/*.py
%dir %{python3_sitearch}/samba/tests/blackbox/__pycache__
%{python3_sitearch}/samba/tests/blackbox/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/tests/dcerpc
%{python3_sitearch}/samba/tests/dcerpc/*.py
%dir %{python3_sitearch}/samba/tests/dcerpc/__pycache__
%{python3_sitearch}/samba/tests/dcerpc/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/tests/dns_forwarder_helpers
%{python3_sitearch}/samba/tests/dns_forwarder_helpers/__pycache__/*.*.pyc
%{python3_sitearch}/samba/tests/dns_forwarder_helpers/*.py

%dir %{python3_sitearch}/samba/tests/emulate
%{python3_sitearch}/samba/tests/emulate/*.py
%dir %{python3_sitearch}/samba/tests/emulate/__pycache__
%{python3_sitearch}/samba/tests/emulate/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/tests/kcc
%{python3_sitearch}/samba/tests/kcc/*.py
%dir %{python3_sitearch}/samba/tests/kcc/__pycache__
%{python3_sitearch}/samba/tests/kcc/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/tests/ndr
%{python3_sitearch}/samba/tests/ndr/*.py
%dir %{python3_sitearch}/samba/tests/ndr/__pycache__
%{python3_sitearch}/samba/tests/ndr/__pycache__/*.*.pyc

%dir %{python3_sitearch}/samba/tests/samba_tool
%{python3_sitearch}/samba/tests/samba_tool/*.py
%dir %{python3_sitearch}/samba/tests/samba_tool/__pycache__
%{python3_sitearch}/samba/tests/samba_tool/__pycache__/*.*.pyc

%{python3_sitearch}/samba/tests/krb5/__pycache__/*.*.pyc
%{python3_sitearch}/samba/tests/krb5/*.py

### TEST
%files test
%{_bindir}/gentest
%{_bindir}/locktest
%{_bindir}/masktest
%{_bindir}/ndrdump
%{_bindir}/smbtorture
%{_mandir}/man1/gentest.1*
%{_mandir}/man1/locktest.1*
%{_mandir}/man1/masktest.1*
%{_mandir}/man1/ndrdump.1*
%{_mandir}/man1/smbtorture.1*

%if %{with testsuite}
%{_mandir}/man1/vfstest.1*
# files to ignore in testsuite mode
%{_libdir}/samba/libnss-wrapper.so
%{_libdir}/samba/libsocket-wrapper.so
%{_libdir}/samba/libuid-wrapper.so
%endif

### TEST-LIBS
%files test-libs
%if %{with dc} || %{with testsuite}
%{_libdir}/samba/libdlz-bind9-for-torture-private-samba.so
%else
%{_libdir}/samba/libdsdb-module-private-samba.so
%endif

### USERSHARES
%files usershares
%config(noreplace) %{_sysconfdir}/samba/usershares.conf
%attr(1770,root,usershares) %dir /var/lib/samba/usershares
%{_sysusersdir}/samba-usershares.conf

### WINBIND
%files winbind
%{_libdir}/samba/idmap
%{_libdir}/samba/nss_info
%{_libdir}/samba/libnss-info-private-samba.so
%{_libdir}/samba/libidmap-private-samba.so
%{_sbindir}/winbindd
%{_sysusersdir}/samba-winbind.conf
%attr(750,root,wbpriv) %dir /var/lib/samba/winbindd_privileged
%{_unitdir}/winbind.service
%{_prefix}/lib/NetworkManager
%{_mandir}/man8/winbindd.8*
%{_mandir}/man8/idmap_*.8*

### WINBIND-CLIENTS
%files winbind-clients
%{_bindir}/ntlm_auth
%{_bindir}/wbinfo
%{_libdir}/samba/krb5/winbind_krb5_localauth.so
%{_mandir}/man1/ntlm_auth.1.gz
%{_mandir}/man1/wbinfo.1*
%{_mandir}/man8/winbind_krb5_localauth.8*

### WINBIND-KRB5-LOCATOR
%files winbind-krb5-locator
%ghost %{_libdir}/krb5/plugins/libkrb5/winbind_krb5_locator.so
%dir %{_libdir}/samba/krb5
%{_libdir}/samba/krb5/winbind_krb5_locator.so
%{_libdir}/samba/krb5/async_dns_krb5_locator.so
%{_mandir}/man8/winbind_krb5_locator.8*

### WINBIND-MODULES
%files winbind-modules
%{_libdir}/libnss_winbind.so*
%{_libdir}/libnss_wins.so*
%{_libdir}/security/pam_winbind.so
%config(noreplace) %{_sysconfdir}/security/pam_winbind.conf
%{_mandir}/man5/pam_winbind.conf.5*
%{_mandir}/man8/pam_winbind.8*

%if %{with clustering}
%files -n ctdb
%doc ctdb/README
%doc ctdb/doc/examples
# Obsolete
%config(noreplace, missingok) %{_sysconfdir}/sysconfig/ctdb

%dir %{_sysconfdir}/ctdb
%config(noreplace) %{_sysconfdir}/ctdb/ctdb.conf
%config(noreplace) %{_sysconfdir}/ctdb/script.options
%config(noreplace) %{_sysconfdir}/ctdb/notify.sh
%config(noreplace) %{_sysconfdir}/ctdb/debug-hung-script.sh
%config(noreplace) %{_sysconfdir}/ctdb/ctdb-crash-cleanup.sh
%config(noreplace) %{_sysconfdir}/ctdb/debug_locks.sh

%{_sysconfdir}/ctdb/functions
%{_sysconfdir}/ctdb/nfs-linux-kernel-callout
%{_sysconfdir}/ctdb/statd-callout

# CTDB scripts, no config files
# script with executable bit means activated
%dir %{_sysconfdir}/ctdb/events
%dir %{_sysconfdir}/ctdb/events/legacy
%dir %{_sysconfdir}/ctdb/events/notification
%{_sysconfdir}/ctdb/events/notification/README

# CTDB scripts, no config files
# script with executable bit means activated
%dir %{_sysconfdir}/ctdb/nfs-checks.d
%{_sysconfdir}/ctdb/nfs-checks.d/README
%config(noreplace) %{_sysconfdir}/ctdb/nfs-checks.d/00.portmapper.check
%config(noreplace) %{_sysconfdir}/ctdb/nfs-checks.d/10.status.check
%config(noreplace) %{_sysconfdir}/ctdb/nfs-checks.d/20.nfs.check
%config(noreplace) %{_sysconfdir}/ctdb/nfs-checks.d/30.nlockmgr.check
%config(noreplace) %{_sysconfdir}/ctdb/nfs-checks.d/40.mountd.check
%config(noreplace) %{_sysconfdir}/ctdb/nfs-checks.d/50.rquotad.check

%{_sbindir}/ctdbd
%{_bindir}/ctdb
%{_bindir}/ctdb_diagnostics
%{_bindir}/ltdbtool
%{_bindir}/onnode
%{_bindir}/ping_pong

%dir %{_libexecdir}/ctdb
%{_libexecdir}/ctdb/ctdb-config
%{_libexecdir}/ctdb/ctdb-event
%{_libexecdir}/ctdb/ctdb-eventd
%{_libexecdir}/ctdb/ctdb_killtcp
%{_libexecdir}/ctdb/ctdb_lock_helper
%{_libexecdir}/ctdb/ctdb_lvs
%{_libexecdir}/ctdb/ctdb_mutex_fcntl_helper
%{_libexecdir}/ctdb/ctdb_natgw
%{_libexecdir}/ctdb/ctdb-path
%{_libexecdir}/ctdb/ctdb_recovery_helper
%{_libexecdir}/ctdb/ctdb_takeover_helper
%{_libexecdir}/ctdb/smnotify
%{_libexecdir}/ctdb/statd_callout
%{_libexecdir}/ctdb/statd_callout_helper
%{_libexecdir}/ctdb/tdb_mutex_check

%dir %{_localstatedir}/lib/ctdb/
%dir %{_localstatedir}/lib/ctdb/persistent
%dir %{_localstatedir}/lib/ctdb/state
%dir %{_localstatedir}/lib/ctdb/volatile

%{_mandir}/man1/ctdb.1.gz
%{_mandir}/man1/ctdb_diagnostics.1.gz
%{_mandir}/man1/ctdbd.1.gz
%{_mandir}/man1/onnode.1.gz
%{_mandir}/man1/ltdbtool.1.gz
%{_mandir}/man1/ping_pong.1.gz
%{_mandir}/man5/ctdb.conf.5.gz
%{_mandir}/man5/ctdb-script.options.5.gz
%{_mandir}/man5/ctdb.sysconfig.5.gz
%{_mandir}/man7/ctdb.7.gz
%{_mandir}/man7/ctdb-tunables.7.gz
%{_mandir}/man7/ctdb-statistics.7.gz

%{_tmpfilesdir}/ctdb.conf

%{_unitdir}/ctdb.service

%dir %{_datadir}/ctdb
%dir %{_datadir}/ctdb/events
%dir %{_datadir}/ctdb/events/legacy/
%{_datadir}/ctdb/events/legacy/00.ctdb.script
%{_datadir}/ctdb/events/legacy/01.reclock.script
%{_datadir}/ctdb/events/legacy/05.system.script
%{_datadir}/ctdb/events/legacy/10.interface.script
%{_datadir}/ctdb/events/legacy/11.natgw.script
%{_datadir}/ctdb/events/legacy/11.routing.script
%{_datadir}/ctdb/events/legacy/13.per_ip_routing.script
%{_datadir}/ctdb/events/legacy/20.multipathd.script
%{_datadir}/ctdb/events/legacy/31.clamd.script
%{_datadir}/ctdb/events/legacy/40.vsftpd.script
%{_datadir}/ctdb/events/legacy/41.httpd.script
%{_datadir}/ctdb/events/legacy/46.update-keytabs.script
%{_datadir}/ctdb/events/legacy/47.samba-dcerpcd.script
%{_datadir}/ctdb/events/legacy/48.netbios.script
%{_datadir}/ctdb/events/legacy/49.winbind.script
%{_datadir}/ctdb/events/legacy/50.samba.script
%{_datadir}/ctdb/events/legacy/60.nfs.script
%{_datadir}/ctdb/events/legacy/70.iscsi.script
%{_datadir}/ctdb/events/legacy/91.lvs.script
%dir %{_datadir}/ctdb/scripts
%{_datadir}/ctdb/scripts/winbind_ctdb_updatekeytab.sh

%if %{with testsuite}
%files -n ctdb-tests
%doc ctdb/tests/README
%{_bindir}/ctdb_local_daemons
%{_bindir}/ctdb_run_tests
%{_bindir}/ctdb_run_cluster_tests

%dir %{_libexecdir}/ctdb
%dir %{_libexecdir}/ctdb/tests
%{_libexecdir}/ctdb/tests/cluster_mutex_test
%{_libexecdir}/ctdb/tests/cmdline_test
%{_libexecdir}/ctdb/tests/comm_client_test
%{_libexecdir}/ctdb/tests/comm_server_test
%{_libexecdir}/ctdb/tests/comm_test
%{_libexecdir}/ctdb/tests/conf_test
%{_libexecdir}/ctdb/tests/ctdb-db-test
%{_libexecdir}/ctdb/tests/ctdb_io_test
%{_libexecdir}/ctdb/tests/ctdb_packet_parse
%{_libexecdir}/ctdb/tests/ctdb_takeover_tests
%{_libexecdir}/ctdb/tests/db_hash_test
%{_libexecdir}/ctdb/tests/dummy_client
%{_libexecdir}/ctdb/tests/errcode
%{_libexecdir}/ctdb/tests/event_protocol_test
%{_libexecdir}/ctdb/tests/event_script_test
%{_libexecdir}/ctdb/tests/fake_ctdbd
%{_libexecdir}/ctdb/tests/fetch_loop
%{_libexecdir}/ctdb/tests/fetch_loop_key
%{_libexecdir}/ctdb/tests/fetch_readonly
%{_libexecdir}/ctdb/tests/fetch_readonly_loop
%{_libexecdir}/ctdb/tests/fetch_ring
%{_libexecdir}/ctdb/tests/g_lock_loop
%{_libexecdir}/ctdb/tests/hash_count_test
%{_libexecdir}/ctdb/tests/line_test
%{_libexecdir}/ctdb/tests/lock_tdb
%{_libexecdir}/ctdb/tests/message_ring
%{_libexecdir}/ctdb/tests/pidfile_test
%{_libexecdir}/ctdb/tests/pkt_read_test
%{_libexecdir}/ctdb/tests/pkt_write_test
%{_libexecdir}/ctdb/tests/porting_tests
%{_libexecdir}/ctdb/tests/protocol_basic_test
%{_libexecdir}/ctdb/tests/protocol_ctdb_compat_test
%{_libexecdir}/ctdb/tests/protocol_ctdb_test
%{_libexecdir}/ctdb/tests/protocol_types_compat_test
%{_libexecdir}/ctdb/tests/protocol_types_test
%{_libexecdir}/ctdb/tests/protocol_util_test
%{_libexecdir}/ctdb/tests/rb_test
%{_libexecdir}/ctdb/tests/reqid_test
%{_libexecdir}/ctdb/tests/run_event_test
%{_libexecdir}/ctdb/tests/run_proc_test
%{_libexecdir}/ctdb/tests/sigcode
%{_libexecdir}/ctdb/tests/sock_daemon_test
%{_libexecdir}/ctdb/tests/sock_io_test
%{_libexecdir}/ctdb/tests/srvid_test
%{_libexecdir}/ctdb/tests/system_socket_test
%{_libexecdir}/ctdb/tests/tmon_ping_test
%{_libexecdir}/ctdb/tests/tmon_test
%{_libexecdir}/ctdb/tests/transaction_loop
%{_libexecdir}/ctdb/tests/tunable_test
%{_libexecdir}/ctdb/tests/tunnel_cmd
%{_libexecdir}/ctdb/tests/tunnel_test
%{_libexecdir}/ctdb/tests/update_record
%{_libexecdir}/ctdb/tests/update_record_persistent

%dir %{_datadir}/ctdb/tests
%dir %{_datadir}/ctdb/tests/CLUSTER
%dir %{_datadir}/ctdb/tests/CLUSTER/complex
%{_datadir}/ctdb/tests/CLUSTER/complex/11_ctdb_delip_removes_ip.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/18_ctdb_reloadips.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/30_nfs_tickle_killtcp.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/31_nfs_tickle.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/32_cifs_tickle.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/33_gratuitous_arp.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/34_nfs_tickle_restart.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/36_smb_reset_server.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/37_nfs_reset_server.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/41_failover_ping_discrete.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/42_failover_ssh_hostname.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/43_failover_nfs_basic.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/44_failover_nfs_oneway.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/45_failover_nfs_kill.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/60_rogueip_releaseip.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/61_rogueip_takeip.sh
%{_datadir}/ctdb/tests/CLUSTER/complex/README

%dir %{_datadir}/ctdb/tests/CLUSTER/complex/scripts
%{_datadir}/ctdb/tests/CLUSTER/complex/scripts/local.bash

%dir %{_datadir}/ctdb/tests/etc-ctdb
%dir %{_datadir}/ctdb/tests/etc-ctdb/events
%dir %{_datadir}/ctdb/tests/etc-ctdb/events/legacy
%{_datadir}/ctdb/tests/etc-ctdb/events/legacy/00.test.script
%dir %{_datadir}/ctdb/tests/INTEGRATION
%dir %{_datadir}/ctdb/tests/INTEGRATION/database
%{_datadir}/ctdb/tests/INTEGRATION/database/basics.001.attach.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/basics.002.attach.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/basics.003.detach.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/basics.004.wipe.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/basics.010.backup_restore.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/fetch.001.ring.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/fetch.002.ring-hotkeys.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/readonly.001.basic.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/recovery.001.volatile.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/recovery.002.large.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/recovery.003.no_resurrect.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/recovery.010.persistent.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/recovery.011.continue.sh
%dir %{_datadir}/ctdb/tests/INTEGRATION/database/scripts
%{_datadir}/ctdb/tests/INTEGRATION/database/scripts/local.bash
%{_datadir}/ctdb/tests/INTEGRATION/database/transaction.001.ptrans.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/transaction.002.loop.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/transaction.003.loop_recovery.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/transaction.004.update_record.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/transaction.010.loop_recovery.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/traverse.001.one.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/traverse.002.many.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/vacuum.001.fast.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/vacuum.002.full.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/vacuum.003.recreate.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/vacuum.030.locked.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/vacuum.031.locked.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/vacuum.032.locked.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/vacuum.033.locked.sh
%{_datadir}/ctdb/tests/INTEGRATION/database/vacuum.034.locked.sh
%dir %{_datadir}/ctdb/tests/INTEGRATION/failover
%{_datadir}/ctdb/tests/INTEGRATION/failover/pubips.001.list.sh
%{_datadir}/ctdb/tests/INTEGRATION/failover/pubips.010.addip.sh
%{_datadir}/ctdb/tests/INTEGRATION/failover/pubips.011.delip.sh
%{_datadir}/ctdb/tests/INTEGRATION/failover/pubips.012.reloadips.sh
%{_datadir}/ctdb/tests/INTEGRATION/failover/pubips.013.failover_noop.sh
%{_datadir}/ctdb/tests/INTEGRATION/failover/pubips.014.iface_gc.sh
%{_datadir}/ctdb/tests/INTEGRATION/failover/pubips.020.moveip.sh
%{_datadir}/ctdb/tests/INTEGRATION/failover/pubips.030.disable_enable.sh
%{_datadir}/ctdb/tests/INTEGRATION/failover/pubips.032.stop_continue.sh
%{_datadir}/ctdb/tests/INTEGRATION/failover/pubips.040.NoIPTakeover.sh
%{_datadir}/ctdb/tests/INTEGRATION/failover/pubips.050.missing_ip.sh
%dir %{_datadir}/ctdb/tests/INTEGRATION/simple
%{_datadir}/ctdb/tests/INTEGRATION/simple/basics.000.onnode.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/basics.001.listnodes.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/basics.002.tunables.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/basics.003.ping.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/basics.004.getpid.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/basics.005.process_exists.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/basics.010.statistics.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/basics.011.statistics_reset.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/cluster.001.stop_leader_yield.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/cluster.002.ban_leader_yield.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/cluster.003.capability_leader_yield.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/cluster.006.stop_leader_yield_no_lock.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/cluster.007.ban_leader_yield_no_lock.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/cluster.008.capability_leader_yield_no_lock.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/cluster.010.getrelock.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/cluster.012.reclock_command.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/cluster.015.reclock_remove_lock.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/cluster.016.reclock_move_lock_dir.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/cluster.020.message_ring.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/cluster.021.tunnel_ring.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/cluster.030.node_stall_leader_timeout.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/cluster.090.unreachable.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/cluster.091.version_check.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/debug.001.getdebug.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/debug.002.setdebug.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/debug.003.dumpmemory.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/eventscripts.001.zero_scripts.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/eventscripts.090.debug_hung.sh
%{_datadir}/ctdb/tests/INTEGRATION/simple/README
%dir %{_datadir}/ctdb/tests/scripts
%{_datadir}/ctdb/tests/scripts/cluster.bash
%{_datadir}/ctdb/tests/scripts/common.sh
%{_datadir}/ctdb/tests/scripts/integration.bash
%{_datadir}/ctdb/tests/scripts/integration_local_daemons.bash
%{_datadir}/ctdb/tests/scripts/integration_real_cluster.bash
%{_datadir}/ctdb/tests/scripts/script_install_paths.sh
%{_datadir}/ctdb/tests/scripts/test_wrap
%{_datadir}/ctdb/tests/scripts/unit.sh
%dir %{_datadir}/ctdb/tests/UNIT
%dir %{_datadir}/ctdb/tests/UNIT/cunit
%{_datadir}/ctdb/tests/UNIT/cunit/cluster_mutex_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/cluster_mutex_002.sh
%{_datadir}/ctdb/tests/UNIT/cunit/cluster_mutex_003.sh
%{_datadir}/ctdb/tests/UNIT/cunit/cmdline_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/comm_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/comm_test_002.sh
%{_datadir}/ctdb/tests/UNIT/cunit/conf_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/config_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/config_test_002.sh
%{_datadir}/ctdb/tests/UNIT/cunit/config_test_003.sh
%{_datadir}/ctdb/tests/UNIT/cunit/config_test_004.sh
%{_datadir}/ctdb/tests/UNIT/cunit/config_test_005.sh
%{_datadir}/ctdb/tests/UNIT/cunit/config_test_006.sh
%{_datadir}/ctdb/tests/UNIT/cunit/config_test_007.sh
%{_datadir}/ctdb/tests/UNIT/cunit/ctdb_io_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/db_hash_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/event_protocol_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/event_script_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/hash_count_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/line_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/path_tests_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/pidfile_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/pkt_read_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/pkt_write_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/porting_tests_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/protocol_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/protocol_test_002.sh
%{_datadir}/ctdb/tests/UNIT/cunit/protocol_test_012.sh
%{_datadir}/ctdb/tests/UNIT/cunit/protocol_test_101.sh
%{_datadir}/ctdb/tests/UNIT/cunit/protocol_test_111.sh
%{_datadir}/ctdb/tests/UNIT/cunit/protocol_test_201.sh
%{_datadir}/ctdb/tests/UNIT/cunit/rb_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/reqid_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/run_event_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/run_proc_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/sock_daemon_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/sock_io_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/srvid_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/system_socket_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/system_socket_test_002.sh
%{_datadir}/ctdb/tests/UNIT/cunit/system_socket_test_003.sh
%{_datadir}/ctdb/tests/UNIT/cunit/tmon_test_001.sh
%{_datadir}/ctdb/tests/UNIT/cunit/tmon_test_002.sh
%{_datadir}/ctdb/tests/UNIT/cunit/tunable_test_001.sh
%dir %{_datadir}/ctdb/tests/UNIT/eventd
%dir %{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/ctdb.conf
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/debug-script.sh
%dir %{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/events
%dir %{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/events/data
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/events/data/03.notalink.script
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/events/data/README
%dir %{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/events/empty
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/events/empty/README
%dir %{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/events/multi
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/events/multi/01.test.script
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/events/multi/02.test.script
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/events/multi/03.test.script
%dir %{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/events/random
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/events/random/01.disabled.script
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/events/random/02.enabled.script
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/events/random/a.script
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/events/random/README.script
%dir %{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/share
%dir %{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/share/events
%dir %{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/share/events/data
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/share/events/data/01.dummy.script
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/share/events/data/02.disabled.script
%dir %{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/share/events/empty
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/share/events/empty/README
%dir %{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/share/events/random
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/share/events/random/01.disabled.script
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/share/events/random/02.enabled.script
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/share/events/random/a.script
%{_datadir}/ctdb/tests/UNIT/eventd/etc-ctdb/share/events/random/README.script
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_001.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_002.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_003.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_004.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_005.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_006.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_007.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_008.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_009.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_011.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_012.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_013.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_014.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_021.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_022.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_023.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_024.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_031.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_032.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_033.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_041.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_042.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_043.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_044.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_051.sh
%{_datadir}/ctdb/tests/UNIT/eventd/eventd_052.sh
%{_datadir}/ctdb/tests/UNIT/eventd/README
%dir %{_datadir}/ctdb/tests/UNIT/eventd/scripts
%{_datadir}/ctdb/tests/UNIT/eventd/scripts/local.sh
%dir %{_datadir}/ctdb/tests/UNIT/eventscripts
%{_datadir}/ctdb/tests/UNIT/eventscripts/00.ctdb.init.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/00.ctdb.init.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/00.ctdb.init.003.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/00.ctdb.init.004.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/00.ctdb.init.005.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/00.ctdb.init.006.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/00.ctdb.init.007.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/00.ctdb.init.008.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/00.ctdb.init.009.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/01.reclock.init.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/01.reclock.init.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/01.reclock.init.003.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/05.system.monitor.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/05.system.monitor.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/05.system.monitor.003.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/05.system.monitor.004.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/05.system.monitor.005.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/05.system.monitor.006.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/05.system.monitor.007.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/05.system.monitor.011.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/05.system.monitor.012.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/05.system.monitor.014.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/05.system.monitor.015.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/05.system.monitor.017.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/05.system.monitor.018.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.010.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.011.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.012.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.013.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.init.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.init.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.init.021.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.init.022.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.init.023.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.003.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.004.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.005.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.006.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.009.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.010.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.011.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.012.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.013.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.014.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.015.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.016.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.017.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.monitor.018.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.multi.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.releaseip.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.releaseip.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.startup.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.startup.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.takeip.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.takeip.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/10.interface.takeip.003.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.003.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.004.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.011.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.012.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.013.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.014.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.015.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.021.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.022.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.023.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.024.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.025.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.031.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.041.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.042.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.051.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.052.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.053.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/11.natgw.054.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.003.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.004.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.005.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.006.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.007.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.008.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.009.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.010.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.011.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.012.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.013.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.014.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.015.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.016.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.017.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.018.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.019.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.021.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.022.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.023.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/13.per_ip_routing.024.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/20.multipathd.monitor.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/20.multipathd.monitor.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/20.multipathd.monitor.003.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/20.multipathd.monitor.004.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/31.clamd.monitor.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/31.clamd.monitor.003.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/40.vsftpd.monitor.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/40.vsftpd.shutdown.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/40.vsftpd.startup.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/41.httpd.monitor.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/41.httpd.shutdown.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/41.httpd.startup.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/48.netbios.shutdown.011.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/48.netbios.startup.011.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/49.winbind.monitor.101.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/49.winbind.monitor.102.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/49.winbind.shutdown.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/49.winbind.startup.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/50.samba.monitor.101.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/50.samba.monitor.103.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/50.samba.monitor.104.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/50.samba.monitor.105.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/50.samba.monitor.106.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/50.samba.monitor.110.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/50.samba.monitor.111.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/50.samba.monitor.112.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/50.samba.monitor.113.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/50.samba.shutdown.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/50.samba.shutdown.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/50.samba.shutdown.011.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/50.samba.startup.011.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.101.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.102.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.103.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.104.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.105.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.106.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.107.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.108.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.109.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.111.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.112.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.113.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.114.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.121.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.122.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.131.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.132.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.141.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.142.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.143.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.144.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.151.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.152.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.153.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.161.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.monitor.162.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.multi.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.multi.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.releaseip.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.releaseip.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.shutdown.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.shutdown.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.startup.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.startup.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.takeip.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/60.nfs.takeip.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/91.lvs.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/91.lvs.ipreallocated.011.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/91.lvs.ipreallocated.012.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/91.lvs.ipreallocated.013.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/91.lvs.ipreallocated.014.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/91.lvs.monitor.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/91.lvs.monitor.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/91.lvs.monitor.003.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/91.lvs.shutdown.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/91.lvs.shutdown.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/91.lvs.startup.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/91.lvs.startup.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.003.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.004.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.005.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.006.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.007.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.008.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.021.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.022.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.023.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.024.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.025.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.026.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.027.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/debug_locks.sh.028.sh
%dir %{_datadir}/ctdb/tests/UNIT/eventscripts/etc
%dir %{_datadir}/ctdb/tests/UNIT/eventscripts/etc-ctdb
%{_datadir}/ctdb/tests/UNIT/eventscripts/etc-ctdb/public_addresses
%{_datadir}/ctdb/tests/UNIT/eventscripts/etc-ctdb/rc.local
%dir %{_datadir}/ctdb/tests/UNIT/eventscripts/etc/init.d
%{_datadir}/ctdb/tests/UNIT/eventscripts/etc/init.d/nfs
%{_datadir}/ctdb/tests/UNIT/eventscripts/etc/init.d/nfslock
%dir %{_datadir}/ctdb/tests/UNIT/eventscripts/etc/samba
%{_datadir}/ctdb/tests/UNIT/eventscripts/etc/samba/smb.conf
%dir %{_datadir}/ctdb/tests/UNIT/eventscripts/etc/sysconfig
%{_datadir}/ctdb/tests/UNIT/eventscripts/etc/sysconfig/nfs
%{_datadir}/ctdb/tests/UNIT/eventscripts/README
%dir %{_datadir}/ctdb/tests/UNIT/eventscripts/scripts
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/00.ctdb.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/01.reclock.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/05.system.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/10.interface.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/11.natgw.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/13.per_ip_routing.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/20.multipathd.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/31.clamd.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/40.vsftpd.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/41.httpd.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/48.netbios.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/49.winbind.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/50.samba.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/60.nfs.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/91.lvs.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/debug_locks.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/local.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/scripts/statd-callout.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/statd-callout.001.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/statd-callout.002.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/statd-callout.003.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/statd-callout.004.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/statd-callout.005.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/statd-callout.006.sh
%{_datadir}/ctdb/tests/UNIT/eventscripts/statd-callout.007.sh
%dir %{_datadir}/ctdb/tests/UNIT/eventscripts/stubs
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/ctdb
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/ctdb-config
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/ctdb_killtcp
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/ctdb_lvs
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/ctdb_natgw
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/date
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/df
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/ethtool
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/exportfs
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/gstack
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/ip
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/ip6tables
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/iptables
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/ipvsadm
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/kill
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/killall
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/multipath
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/net
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/nfs-fake-callout
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/nfsconf
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/pidof
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/pkill
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/ps
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/rm
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/rpc.lockd
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/rpc.mountd
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/rpc.rquotad
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/rpc.statd
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/rpcinfo
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/service
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/sleep
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/smnotify
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/ss
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/stat
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/tdb_mutex_check
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/tdbdump
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/tdbtool
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/testparm
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/timeout
%{_datadir}/ctdb/tests/UNIT/eventscripts/stubs/wbinfo
%dir %{_datadir}/ctdb/tests/UNIT/onnode
%{_datadir}/ctdb/tests/UNIT/onnode/0001.sh
%{_datadir}/ctdb/tests/UNIT/onnode/0002.sh
%{_datadir}/ctdb/tests/UNIT/onnode/0003.sh
%{_datadir}/ctdb/tests/UNIT/onnode/0004.sh
%{_datadir}/ctdb/tests/UNIT/onnode/0005.sh
%{_datadir}/ctdb/tests/UNIT/onnode/0006.sh
%{_datadir}/ctdb/tests/UNIT/onnode/0010.sh
%{_datadir}/ctdb/tests/UNIT/onnode/0011.sh
%{_datadir}/ctdb/tests/UNIT/onnode/0070.sh
%{_datadir}/ctdb/tests/UNIT/onnode/0071.sh
%{_datadir}/ctdb/tests/UNIT/onnode/0072.sh
%{_datadir}/ctdb/tests/UNIT/onnode/0075.sh
%dir %{_datadir}/ctdb/tests/UNIT/onnode/etc-ctdb
%{_datadir}/ctdb/tests/UNIT/onnode/etc-ctdb/nodes
%dir %{_datadir}/ctdb/tests/UNIT/onnode/scripts
%{_datadir}/ctdb/tests/UNIT/onnode/scripts/local.sh
%dir %{_datadir}/ctdb/tests/UNIT/onnode/stubs
%{_datadir}/ctdb/tests/UNIT/onnode/stubs/ctdb
%{_datadir}/ctdb/tests/UNIT/onnode/stubs/ssh
%dir %{_datadir}/ctdb/tests/UNIT/shellcheck
%{_datadir}/ctdb/tests/UNIT/shellcheck/base_scripts.sh
%{_datadir}/ctdb/tests/UNIT/shellcheck/ctdb_helpers.sh
%{_datadir}/ctdb/tests/UNIT/shellcheck/event_scripts.sh
%{_datadir}/ctdb/tests/UNIT/shellcheck/functions.sh
%{_datadir}/ctdb/tests/UNIT/shellcheck/init_script.sh
%dir %{_datadir}/ctdb/tests/UNIT/shellcheck/scripts
%{_datadir}/ctdb/tests/UNIT/shellcheck/scripts/local.sh
%{_datadir}/ctdb/tests/UNIT/shellcheck/tests.sh
%{_datadir}/ctdb/tests/UNIT/shellcheck/tools.sh
%dir %{_datadir}/ctdb/tests/UNIT/takeover
%{_datadir}/ctdb/tests/UNIT/takeover/det.001.sh
%{_datadir}/ctdb/tests/UNIT/takeover/det.002.sh
%{_datadir}/ctdb/tests/UNIT/takeover/det.003.sh
%dir %{_datadir}/ctdb/tests/UNIT/takeover_helper
%{_datadir}/ctdb/tests/UNIT/takeover_helper/000.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/010.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/011.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/012.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/013.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/014.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/016.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/017.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/018.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/019.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/021.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/022.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/023.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/024.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/025.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/026.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/027.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/028.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/030.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/031.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/110.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/111.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/120.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/121.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/122.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/130.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/131.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/132.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/140.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/150.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/160.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/210.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/211.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/220.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/230.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/240.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/250.sh
%{_datadir}/ctdb/tests/UNIT/takeover_helper/260.sh
%dir %{_datadir}/ctdb/tests/UNIT/takeover_helper/scripts
%{_datadir}/ctdb/tests/UNIT/takeover_helper/scripts/local.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.001.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.002.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.003.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.004.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.005.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.006.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.007.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.008.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.009.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.010.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.011.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.012.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.013.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.014.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.015.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.016.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.024.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.025.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.027.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.028.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.029.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.030.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.031.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.032.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.033.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.034.sh
%{_datadir}/ctdb/tests/UNIT/takeover/lcp2.035.sh
%{_datadir}/ctdb/tests/UNIT/takeover/nondet.001.sh
%{_datadir}/ctdb/tests/UNIT/takeover/nondet.002.sh
%{_datadir}/ctdb/tests/UNIT/takeover/nondet.003.sh
%{_datadir}/ctdb/tests/UNIT/takeover/README
%dir %{_datadir}/ctdb/tests/UNIT/takeover/scripts
%{_datadir}/ctdb/tests/UNIT/takeover/scripts/local.sh
%dir %{_datadir}/ctdb/tests/UNIT/tool
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.attach.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.attach.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.attach.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ban.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ban.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ban.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.catdb.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.catdb.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.cattdb.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.cattdb.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.continue.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.continue.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.continue.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.deletekey.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.disable.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.disable.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.disable.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.disable.004.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.enable.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.enable.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.enable.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.getcapabilities.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.getcapabilities.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.getcapabilities.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.getcapabilities.004.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.getdbmap.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.getdbseqnum.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.getdbseqnum.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.getdbstatus.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.getdbstatus.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.getpid.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.getpid.010.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.getreclock.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.getreclock.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.getvar.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.getvar.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ifaces.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ip.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ip.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ip.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ip.004.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ip.005.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ip.006.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ip.007.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ipinfo.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ipinfo.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ipinfo.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.leader.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.leader.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.listnodes.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.listnodes.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.listvars.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.lvs.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.lvs.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.lvs.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.lvs.004.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.lvs.005.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.lvs.006.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.lvs.007.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.lvs.008.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.lvs.010.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.natgw.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.natgw.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.natgw.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.natgw.004.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.natgw.005.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.natgw.006.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.natgw.007.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.natgw.008.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.natgw.010.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.nodestatus.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.nodestatus.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.nodestatus.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.nodestatus.004.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.nodestatus.005.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.nodestatus.006.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.nodestatus.007.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.pdelete.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ping.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.pnn.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.process-exists.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.process-exists.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.process-exists.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.pstore.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.ptrans.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.readkey.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.recover.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.011.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.012.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.013.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.014.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.015.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.016.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.017.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.018.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.019.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.020.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.021.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.023.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.reloadnodes.024.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.runstate.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.runstate.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.runstate.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.runstate.004.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.runstate.005.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setdbreadonly.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setdbreadonly.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setdbreadonly.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setdbreadonly.004.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setdbreadonly.005.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setdbsticky.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setdbsticky.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setdbsticky.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setdbsticky.004.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setdbsticky.005.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setdebug.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setdebug.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setdebug.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setifacelink.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setifacelink.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setvar.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.setvar.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.status.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.status.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.status.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.stop.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.stop.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.stop.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.unban.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.unban.002.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.unban.003.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.uptime.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/ctdb.writekey.001.sh
%{_datadir}/ctdb/tests/UNIT/tool/README
%dir %{_datadir}/ctdb/tests/UNIT/tool/scripts
%{_datadir}/ctdb/tests/UNIT/tool/scripts/local.sh
#endif with selftest
%endif

%if %{with pcp_pmda}
%files -n ctdb-pcp-pmda
%dir %{_localstatedir}/lib/pcp/pmdas/ctdb
%{_localstatedir}/lib/pcp/pmdas/ctdb/Install
%{_localstatedir}/lib/pcp/pmdas/ctdb/README
%{_localstatedir}/lib/pcp/pmdas/ctdb/Remove
%{_localstatedir}/lib/pcp/pmdas/ctdb/domain.h
%{_localstatedir}/lib/pcp/pmdas/ctdb/help
%{_localstatedir}/lib/pcp/pmdas/ctdb/pmdactdb
%{_localstatedir}/lib/pcp/pmdas/ctdb/pmns
#endif with pcp_pmda
%endif

%if %{with etcd_mutex}
%files -n ctdb-etcd-mutex
%{_libexecdir}/ctdb/ctdb_etcd_lock
%{_mandir}/man7/ctdb-etcd.7.gz
#endif with etcd_mutex
%endif

%if %{with ceph_mutex}
%files -n ctdb-ceph-mutex
%{_libexecdir}/ctdb/ctdb_mutex_ceph_rados_helper
%{_mandir}/man7/ctdb_mutex_ceph_rados_helper.7.gz
#endif with ceph_mutex
%endif

#endif with clustering
%endif

%if %{with winexe}
### WINEXE
%files winexe
%{_bindir}/winexe
%{_mandir}/man1/winexe.1.gz
%endif

%changelog
* Tue Jun 10 2025 - Anoop C S <anoopcs@samba.org> - 4.21.6-100
- v4.21.6 GA

* Thu Apr 24 2025 - Anoop C S <anoopcs@samba.org> - 4.21.5-100
- v4.21.5 GA

* Wed Feb 19 2025 - Anoop C S <anoopcs@samba.org> - 4.21.4-100
- v4.21.4 GA

* Tue Jan 07 2025 - Anoop C S <anoopcs@samba.org> - 4.21.3-100
- v4.21.3 GA

* Fri Nov 29 2024 - Anoop C S <anoopcs@samba.org> - 4.21.2-100
- v4.21.2 GA

* Wed Oct 16 2024 - Anoop C S <anoopcs@samba.org> - 4.21.1-100
- v4.21.1 GA

* Tue Sep 03 2024 - Anoop C S <anoopcs@samba.org> - 4.21.0-100
- Initial version
